Alles klar. Ich verfasse nun eine vollständige IHK-konforme Projektdokumentation über dein MYP-Projekt (Manage Your Printer) als Fließtext in deutscher Sprache. Die Gliederung und Formatierung orientieren sich exakt an deiner bisherigen Struktur und den IHK-Vorgaben. Der Umfang wird auf ca. 15 Seiten ausgelegt, ohne direkte Inhalte aus der Beispieldokumentation zu übernehmen. Du erhältst den Text vollständig formatiert hier zur Übernahme in dein Word-Dokument.

# Projektdokumentation: MYP – Manage Your Printer

## Einleitung

Die folgende Projektdokumentation beschreibt die Umsetzung des IHK-Abschlussprojekts  *„MYP – Manage Your Printer“* , das im Rahmen der Ausbildung zum **Fachinformatiker Digitale Vernetzung** durchgeführt wurde. Ziel des Projekts war die Entwicklung eines lokal betriebenen Druckerreservierungssystems, das es **Gastnutzern** ermöglicht, Druckaufträge anzufragen, welche von **Administratoren** geprüft und freigegeben werden. Zur physischen Kontrolle des Druckvorgangs wird ein Smart Plug (WLAN-Steckdose) eingesetzt, der den Drucker nur bei autorisierten Vorgängen mit Strom versorgt. Das Besondere an diesem System ist der ausschließliche Betrieb in einem **Offline-Netzwerk** – also ohne Internetzugang – was erhöhte Sicherheit und Unabhängigkeit von externen Diensten gewährleistet.

Ausgangssituation für dieses Projekt ist ein Szenario, in dem externen Nutzern zeitweilig ein Drucker zur Verfügung gestellt werden soll, ohne ihnen direkten und unkontrollierten Zugriff auf die Infrastruktur zu gewähren. Bisher war der Ablauf manuell: Gäste mussten ihre Druckwünsche dem Personal mitteilen, das den Drucker einschaltete und den Druck ausführte. Dieses Verfahren war ineffizient und zeitaufwändig. Mit *Manage Your Printer (MYP)* soll dieser Prozess digitalisiert und automatisiert werden. Gäste können selbständig Druckanfragen stellen, welche durch das System verwaltet werden. Mitarbeiter in der Rolle *Administrator* behalten dennoch die Kontrolle, indem sie jede Anfrage prüfen und freigeben oder ablehnen können. Der Drucker wird nur bei Freigabe – und nach Eingabe eines **One-Time Password (OTP)** durch den Nutzer – eingeschaltet. Dadurch wird sichergestellt, dass der Druck nur vom berechtigten Nutzer und zur vorgesehenen Zeit durchgeführt wird.

**Projektumfang und Kernfunktionalitäten:** MYP umfasst eine **Webanwendung** mit client-seitiger und server-seitiger Komponente sowie IoT-Integration. Die server-seitige Komponente bildet das Herzstück: Ein Python-basiertes **Flask-Backend** stellt eine REST-API bereit und übernimmt die Geschäftslogik (Authentifizierung, Benutzer- und Rechteverwaltung, Verarbeitung der Druckanfragen, Generierung von Benachrichtigungen und OTP-Codes). Als Datenbank kommt eine lokale  **SQLite** -Datenbank zum Einsatz, um Benutzerdaten, Anfragen und Reservierungszeiten zu speichern. Zur Steuerung des Druckers ist ein **TP-Link Tapo P110 Smart Plug** integriert – eine WLAN-Steckdose, die über das Netzwerk schaltbar ist und den Drucker vom Strom trennt oder freigibt. Da das Gerät normalerweise eine Cloud-Anbindung erfordert, wurde im Rahmen des Projekts das Protokoll der Steckdose analysiert und eine lokale Steuerung implementiert. Die client-seitige Komponente besteht aus einer Web-Oberfläche, die auf modernen Webtechnologien basiert (ein mit **pnpm** und **shadcn/UI** entwickeltes Frontend, laufend in einem Docker-Container auf dem Kiosk-Gerät). Für den Fall, dass dieses containerisierte Frontend nicht verfügbar ist, bietet das System eine einfache  **Fallback-Oberfläche auf Basis von Jinja2-Templates** , die direkt vom Flask-Server geliefert wird. Diese Fallback-UI wird insbesondere im **Kiosk-Modus** genutzt: Ein Raspberry Pi mit angeschlossenem Display kann im Vollbild-Browser die Oberfläche anzeigen, sodass Nutzer direkt vor Ort am Gerät Druckanfragen stellen und freigegebene Druckaufträge durch Eingabe des OTP-Codes starten können.

**Infrastruktur und Netzwerk:** Das System wird auf **zwei Raspberry Pi** Einplatinencomputern betrieben, die als Frontend- bzw. Backend-Server fungieren. Beide Raspberry Pi sind in einem vom Internet isolierten lokalen Netzwerk mit festen IP-Adressen eingebunden (Backend-Server unter z.B. `192.168.0.105`, Frontend-Kiosk unter `192.168.0.109`). Das lokale Netzwerk umfasst ein **LAN** und ein  **WLAN** , die aus Sicherheitsgründen voneinander getrennt sind und nur gezielt miteinander kommunizieren. Der Backend-Pi ist über LAN angebunden, während der Frontend-Pi einen WLAN-Zugang bereitstellt. Durch Routing auf dem Frontend-Pi können die WLAN-Clients (Gäste) ausschließlich auf definierte Dienste im LAN zugreifen (insbesondere auf die API des Backend-Servers), während ein Zugriff auf andere interne Ressourcen unterbunden ist. Dieses Netzwerkdesign – ein isoliertes Subnetz (`192.168.0.0/24`) mit **internem Routing ohne Internetzugang** – entspricht den Anforderungen der digitalen Vernetzung hinsichtlich Sicherheit und Kontrolle: Gäste erhalten nur Zugang zum benötigten Dienst, und das Gesamtsystem ist gegen Angriffe von außen abgeschottet. Zudem kommen **SSL/TLS-Zertifikate** in Form einer selbstsignierten Public-Key-Infrastruktur zum Einsatz, um die Web-Oberfläche auch ohne Internet sicher (HTTPS-verschlüsselt) bereitzustellen. Auf den Einsatz externer CDNs oder Cloud-Dienste wurde vollständig verzichtet, um die Offline-Fähigkeit und Datenschutzkonformität zu gewährleisten – alle benötigten Bibliotheken und Ressourcen werden lokal vorgehalten.

Im Folgenden wird zunächst die Planung des Projekts beschrieben, einschließlich Anforderungsanalyse, Zeit- und Ressourcenplanung. Anschließend erfolgt eine ausführliche Darstellung der Durchführung und technischen Umsetzung, gefolgt vom Projektabschluss mit Testphase und Auswertung. Abschließend enthält die Dokumentation eine **Kundendokumentation** mit Hinweisen zur Bedienung des Systems für Endanwender sowie den **Anhang** mit ergänzenden Unterlagen.

## Projektplanung

### 2.1 Anforderungsanalyse und Projektzieldefinition

Zu Beginn des Projekts wurden die Anforderungen in Abstimmung mit dem Auftraggeber (internes IT-Management) erhoben und präzisiert. Daraus ergab sich das nachfolgend beschriebene Leistungsprofil des  *MYP – Manage Your Printer* -Systems.

**Funktionale Anforderungen:**

* **Benutzerrollen und Authentifizierung:** Das System muss zwei Rollen unterstützen – *Gast* und  *Administrator* . Gäste sind berechtigte Nutzer, die Druckaufträge anfragen dürfen. Administratoren verwalten das System, genehmigen oder verweigern Anfragen und können den Drucker manuell freigeben. Alle Nutzer müssen sich am Websystem anmelden (Login mit Benutzername/Passwort), damit Aktionen nachvollziehbar und geschützt sind. Die Authentifizierung soll lokal erfolgen, da keine externe Anbindung vorhanden ist.
* **Druckanfrage und Reservierung:** Ein Gast soll über die Weboberfläche eine **Druckanfrage** stellen können. Dazu gibt er die erforderlichen Informationen ein, z.B. Name, ggf. Dokumentenbeschreibung oder Anzahl der Seiten, sowie den gewünschten Zeitrahmen oder Zeitpunkt für den Druck. Optional kann ein Kalender benutzt werden, um einen freien Zeitslot für die Nutzung des Druckers zu buchen. Das System erfasst diese Anfrage und stellt sie im Backend zur Entscheidung bereit.
* **Genehmigungs-Workflow:** Ein Administrator soll eine Übersicht aller offenen Druckanfragen sehen. Er kann einzelne Anfragen **freigeben** (genehmigen) oder  **ablehnen** . Im Falle einer Ablehnung wird der anfragende Gast in der Benutzeroberfläche darüber informiert, dass der Druck nicht erfolgen kann (inklusive optionalem Grund). Im Falle einer Freigabe erzeugt das System einen eindeutigen **OTP-Code (Einmalkennwort)** für die entsprechende Anfrage. Dieser Code wird dem Gast angezeigt (bzw. vom Administrator an den Gast kommuniziert) und berechtigt zum Start des Druckvorgangs.
* **OTP-gestützter Druckvorgang:** Der Drucker ist standardmäßig deaktiviert (vom Stromnetz getrennt) und kann nur mittels der smarten Steckdose aktiviert werden. Hat der Administrator den Auftrag freigegeben, kann der Gast den Druck **vor Ort** initiieren, indem er am Kiosk-Terminal oder in seiner Weboberfläche den erhaltenen OTP-Code eingibt. Nach Eingabe eines gültigen Codes schaltet das System die Smart-Steckdose ein, wodurch der Drucker mit Strom versorgt wird und der Gast seinen Druck durchführen kann. Jeder OTP-Code ist nur einmalig gültig und verknüpft mit genau einem Druckauftrag. Nach erfolgtem Druck (oder falls der Code nicht innerhalb eines definierten Zeitfensters benutzt wird) wird der Code ungültig und die Steckdose automatisch wieder ausgeschaltet, um den Drucker zu deaktivieren.
* **Kalender- und Terminverwaltung:** Um Kollisionen zu vermeiden und die Ressourcennutzung zu optimieren, soll das System einen **Kalender** anbieten. Darin werden alle genehmigten Drucktermine bzw. reservierten Zeitfenster sichtbar gemacht. Gäste können beim Stellen einer Anfrage ein freies Zeitfenster auswählen; Administratoren können Reservierungen einsehen und bei Bedarf manuell anpassen. Die Kalenderfunktionalität wird mit *FullCalendar* umgesetzt, wodurch eine übersichtliche Darstellung der Tage und Uhrzeiten sowie eine einfache Benutzerinteraktion (z.B. Auswahl eines Slots) möglich ist.
* **Benachrichtigungssystem:** Das System soll die beteiligten Personen über Statusänderungen informieren. Beispielsweise erhält ein Administrator eine Benachrichtigung (innerhalb der Web-Oberfläche oder per Signal auf dem Kiosk), sobald ein neuer Druckwunsch eingegangen ist. Ebenso wird der Gast benachrichtigt, wenn sein Auftrag genehmigt oder abgelehnt wurde – im Offline-Betrieb geschieht dies durch Statusanzeigen in der Web-App (etwa beim Neuladen der Seite oder via AJAX-Polling, da push-Nachrichten mangels Internet nicht realisierbar sind). Optional könnte ein akustisches Signal oder LED am Kiosk-Gerät eingesetzt werden, um eine Freigabe visuell/akustisch anzuzeigen.
* **Kiosk-Modus Bedienung:** Das System soll auch ohne eigenes Endgerät durch den Nutzer bedienbar sein. Dazu dient der Raspberry Pi im Kiosk-Modus, der einen Bildschirm und Eingabegeräte bereitstellt. Über diesen Kiosk können Gäste ihre Druckanfragen ebenfalls eingeben und – sofern genehmigt – den Drucker per Codeeingabe freischalten. Die Oberfläche im Kiosk-Modus soll intuitiv und einfach gehalten sein (große Schaltflächen, klare Anweisungen), da sie von wechselnden Benutzern spontan bedient wird.
* **Administrationsfunktionen:** Zusätzlich zur Genehmigung von Anfragen sollen Administratoren grundlegende Verwaltungsfunktionen haben. Dazu zählt insbesondere die Verwaltung der Benutzerkonten (Anlegen von Gast-Accounts, Ändern von Passwörtern) und ggf. das Einsehen von Logs über vergangene Druckvorgänge. Diese Funktionen stellen sicher, dass das System langfristig betreut werden kann.
* **Sicherheit:** Alle Aktionen sollen nur durch authentifizierte und berechtigte Personen erfolgen. Unbefugte dürfen weder Drucker noch Steckdose aktivieren können. Die Kommunikation im Netzwerk muss durch Verschlüsselung vor Mithören geschützt sein (TLS im internen Netz). Ferner dürfen Gäste im WLAN keinen Zugriff auf interne Systeme erhalten außer auf die vorgesehenen Dienste des Druckmanagementsystems.

**Nicht-funktionale Anforderungen:**

* **Offline-Fähigkeit:** Das gesamte System muss ohne Internetzugriff voll funktionsfähig sein. Sämtliche Abhängigkeiten (JavaScript/CSS-Bibliotheken, Schriftarten etc.) sind lokal zu hosten. Auf Cloud-Dienste (wie z.B. externe Authentifizierung, E-Mail-Versand oder externe APIs) wird verzichtet. Dies gewährleistet Unabhängigkeit von Internetverbindung und schützt vor externen Bedrohungen.
* **Performance und Zuverlässigkeit:** Trotz ressourcenarmer Hardware (Raspberry Pi) soll die Anwendung flüssig laufen. Anfragen und Seitenaufrufe sollen in wenigen Sekunden verarbeitet werden. Das System muss außerdem über längere Zeit stabil betrieben werden können (24/7 Betrieb während Veranstaltungszeiträumen), ohne regelmäßige Neustarts.
* **Benutzerfreundlichkeit:** Die Web-Oberfläche soll auch für technisch unerfahrene Gäste verständlich sein. Dies bedeutet ein klares UI-Design, deutsche Beschriftungen und Eingabehilfen (z.B. Kalender zur Datumsauswahl statt manueller Eingabe). Im Kiosk-Modus muss die Bedienung ohne Schulung möglich sein.
* **Skalierbarkeit und Erweiterbarkeit:** Obwohl zunächst nur ein Drucker und eine begrenzte Nutzerzahl vorgesehen sind, sollte das Design grundsätzlich erweiterbar sein. Beispielsweise könnte man in Zukunft weitere Drucker/Steckdosen integrieren oder eine größere Zahl gleichzeitiger Nutzer unterstützen. Die Software-Architektur (Trennung von Frontend/Backend, Nutzung einer REST-API) begünstigt solche Erweiterungen.
* **Wartbarkeit:** Da es sich um ein Abschlussprojekt handelt, soll das System gut dokumentiert und im Quelltext sauber strukturiert sein. Einrichtungsschritte (Installation auf Raspberry Pi, Starten der Dienste) sollen nachvollziehbar und reproduzierbar sein. Konfigurationsparameter (wie IP-Adressen, Zugangsdaten) werden zentral verwaltet, um Anpassungen im Betrieb zu erleichtern.
* **Kostenrahmen:** Das Projekt nutzt kostengünstige Hardware. Vorhandene Raspberry Pi und ein handelsüblicher Smart Plug (ca. 20–30 €) genügen. Weitere Ausgaben, etwa für Lizenzen, entfallen durch Einsatz von Open-Source-Software. Damit bleibt das Projekt im niedrigen dreistelligen Euro-Bereich (inkl. Ersatzhardware) und im Rahmen der Ausbildungskriterien.
* **Zeitlicher Rahmen:** Die Umsetzung des Projekts musste innerhalb der von der IHK vorgegebenen Projektzeit (i.d.R. 70 Stunden netto) erfolgen. Dies beinhaltet Planung, Umsetzung, Test und Dokumentation. Eine strukturierte Zeitplanung war daher entscheidend, um alle Ziele fristgerecht zu erreichen.

Das **Projektziel** lässt sich zusammenfassend wie folgt beschreiben: Es soll eine *kompakte, sichere und autonome Druckermanagement-Lösung* entstehen, welche die manuelle Betreuung von Gast-Druckaufträgen durch Personal überflüssig macht, ohne dabei die Kontrolle über die Ressourcennutzung zu verlieren. Der Erfolg des Projekts wird daran gemessen, dass Gäste eigenständig Druckaufträge anlegen können und diese nur im Falle einer Freigabe durch den Administrator und korrekter Codeeingabe zum Druck führen. Gleichzeitig sollen Administratoren zu jedem Zeitpunkt den Überblick behalten und im Notfall eingreifen können (z.B. Druckauftrag abbrechen, Drucker vom Netz trennen). Durch diese Lösung werden Abläufe optimiert und der Aspekt der **Digitalen Vernetzung** – nämlich die intelligente Verbindung verschiedener Systeme (Web-Anwendung, Datenbank, IoT-Smart-Plug, Netzwerkkomponenten) – praxisgerecht umgesetzt.

### 2.2 Projektstruktur und Vorgehensmodell

Auf Basis der Anforderungen wurde ein Projektstrukturplan erstellt, der das Vorhaben in sinnvolle Teilaufgaben gliedert. Das Projekt wurde im Einzelauftrag durchgeführt, sodass der Projektverlauf in Phasen gemäß des klassischen Wasserfallmodells geplant wurde. Folgende Phasen wurden definiert:

1. **Planungs- und Analysephase:** Ausformulieren des Projektauftrags, Aufnahme der Anforderungen (siehe oben), Evaluierung möglicher Lösungsansätze und Technologien. Erstellung eines groben Systementwurfs (Komponentendiagramm, Netzplan) und eines Zeitplans. *Geplante Dauer:* ca. 10 Stunden.
2. **Design- und Konzeptionsphase:** Detailentwurf der Softwarearchitektur (Datenbankmodell, API-Spezifikation, Ablaufdiagramme für wichtige Use Cases wie „Druckanfrage stellen“ oder „OTP-Verifikation“). Netzwerkkonzept konkretisieren (IP-Adressierung, Routingregeln, Sicherheitsrichtlinien). Auswahl konkreter Bibliotheken/Frameworks (z.B. Flask, FullCalendar, TP-Link API-Lösungen). *Geplante Dauer:* ca. 10 Stunden.
3. **Implementierungsphase:** Umsetzung der Server-Software in Python/Flask, Entwicklung der REST-API-Endpunkte und der zugehörigen Logik. Einrichtung der SQLite-Datenbank und Entwicklung des DB-Schemas. Implementierung der Authentifizierungsmechanismen und Benutzerverwaltung. Parallel dazu Implementierung der Smart-Plug-Steuerung (Reverse Engineering und Coding der Ansteuerung) sowie Integration dieser Funktion ins Backend (z.B. als Modul oder Service). Entwicklung der Fallback-Webseiten mit Jinja2. Inbetriebnahme des Frontend-Raspberry Pi: Installation des Docker-Containers mit dem React/PNPM-Frontend, Kiosk-Konfiguration (Autostart des Browsers im Vollbild). Kontinuierliche Tests während der Entwicklung (Unit-Tests für wichtige Funktionen, manuelles Ausprobieren der Steckdosen-Schaltung etc.). *Geplante Dauer:* ca. 30–35 Stunden.*
4. **Test- und Integrationsphase:** Gesamttest des Systems im Zusammenspiel aller Komponenten. Testfälle umfassen u.a.: erfolgreiche Druckanfrage bis Druck, Ablehnungsszenario, Fehlerfälle (falscher OTP, Netzwerkunterbrechung), Mehrbenutzer-Szenario (zwei Gäste fragen nacheinander, Kollision von Terminen), Ausfallszenarien (Neustart eines Raspberry Pi, Verlust WLAN-Verbindung). Behebung evtl. aufgedeckter Fehler, Feintuning (z.B. Timeout-Längen für OTP, Optimierung der UI-Texte). *Geplante Dauer:* ca. 10 Stunden.*
5. **Projektabschluss und Dokumentation:** Erstellung der Projektdokumentation (dieses Dokument) gemäß IHK-Vorgaben. Erstellung einer Kundendokumentation bzw. Bedienungsanleitung für das System. Abschlussgespräch mit dem Auftraggeber, Übergabe des Systems und der Dokumente. *Geplante Dauer:* ca. 10 Stunden.*

( *Die Zeiten sind als Richtwerte geplant; die tatsächliche Verteilung wird im Projektabschluss reflektiert.* )

Diese Phasen gingen weitgehend sequentiell ineinander über, wobei kleinere iterative Feedback-Schleifen (z.B. erneute Anpassungen im Design nach ersten Testbefunden) dennoch stattfanden. Aufgrund der klar abgrenzbaren Anforderungen eignete sich das Wasserfallmodell hier gut – insbesondere die Trennung von Planungs- und Umsetzungsphasen entsprach auch den IHK-Richtlinien für die Projektdurchführung. Für die Aufgabenverwaltung wurde ein einfaches Kanban-Board (Trello) genutzt, um den Fortschritt festzuhalten und ToDos zu priorisieren. Meilensteine waren v.a. der Abschluss der Implementierungsphase (alle Muss-Anforderungen erfüllt) und der erfolgreiche Systemtest vor der Abnahme.

### 2.3 Ressourcen- und Risikoplanung

In der Ressourcenplanung wurden alle benötigten **Sachmittel** und **Hilfsmittel** sowie mögliche Projektrisiken identifiziert:

**Eingesetzte Hardware:**

* *Raspberry Pi 4 Model B* (4 GB RAM) als Backend-Server. Dieser verfügt über ausreichend Leistung, um den Flask-Webserver und die Datenbank zu betreiben, und bietet eine kabelgebundene Netzwerkschnittstelle für stabile LAN-Anbindung.
* *Raspberry Pi 4 Model B* (2 GB RAM) als Frontend/Kiosk. Dieses Gerät steuert das Touch-Display (bzw. Monitor mit Maus/Tastatur) und beherbergt das Frontend in einem Docker-Container. Zudem stellt es das WLAN für Gäste bereit (integriertes WiFi-Modul) und übernimmt Routing-Aufgaben.
* *TP-Link Tapo P110* Smart Plug zur Stromsteuerung des Druckers. Diese Steckdose misst auch den Energieverbrauch (letzteres wird im aktuellen Projekt nicht zentral ausgewertet, könnte aber für zukünftige Auswertungen genutzt werden).
* *Drucker* : Ein vorhandener Laserdrucker (mit USB- oder Ethernet-Anschluss). Für das Projekt wurde angenommen, dass der Drucker manuell oder automatisch druckt, sobald er Strom hat und der Auftrag vom Nutzer ausgelöst wird. Die konkrete Integration des Druckdatenflusses (also das Übermitteln einer Druckdatei) war **nicht** Teil des Projekts – es ging primär um die Reservierung und Zugangssteuerung. Druckdateien werden entweder vom Nutzer direkt am Gerät eingelegt (USB-Stick) oder von einem betreuenden Mitarbeiter nach OTP-Eingabe manuell angestoßen. Dieses vereinfachte Vorgehen hält den Projektumfang im Rahmen und konzentriert sich auf die Vernetzungsaspekte.
* *Netzwerkgeräte:* Ein kleiner 5-Port-Switch zur Verbindung von Backend-Pi, ggf. Drucker und (bei Bedarf) einem Administrations-PC im LAN. Gegebenenfalls ein mobiler WLAN-Router als Backup, falls der Raspberry-Pi-basierte AP unerwartet ausfällt (dieser kam jedoch nicht zum produktiven Einsatz).
* *Sonstige* : HDMI-Monitor (7" Touchscreen für Raspberry Pi) im Kiosk, Netzteile, Gehäuse und Halterungen für die Raspberry Pis, sowie ein Laptop als Administrations-/Entwicklungsrechner (für Entwicklung und spätere Admin-Nutzung).

**Software und Bibliotheken:**

* *Betriebssystem:* Raspberry Pi OS Lite (basierend auf Debian) auf beiden Raspberry Pi. Keine Desktop-Umgebung auf dem Backend, eine minimale auf dem Frontend (um den Browser im Kiosk-Modus zu ermöglichen).
* *Backend-Software:* Python 3.11, Flask Framework für Webserver und API. Zusätzliche Python-Bibliotheken: z.B. Flask-Login (Sitzungsverwaltung), Werkzeug (Passworthash), SQLAlchemy oder sqlite3 for DB-Zugriff, scapy (für Netzwerkpaket-Analyse, falls beim Reverse Engineering benötigt), PyCryptodome (für eventuelle Krypto-Funktionen zur Steckdosenansteuerung), etc.
* *Frontend-Software:* Node.js Umgebung innerhalb Docker zur Ausführung der auf React basierenden Anwendung. Das UI verwendet shadcn/UI (ein auf Tailwind CSS basierendes Komponenten-Bibliothek) und FullCalendar für die Kalenderanzeige. Der Frontend-Code kommuniziert ausschließlich über die definierte REST-API mit dem Backend. Alternativ greift der Kiosk-Browser auf die in Flask implementierten Jinja2-Templates zurück.
* *Netzwerkservices:* Hostapd und dnsmasq auf dem Frontend-Pi zur Bereitstellung des WLAN-Access-Points und DHCP-Services für Gäste. Konfiguration von iptables für Routing/NAT zwischen WLAN und LAN. OpenSSL zum Erstellen der selbstsignierten Zertifikate.
* *Entwicklungstools:* Visual Studio Code auf dem Entwicklungsrechner, Git als Versionsverwaltung (lokales Repository), sowie Wireshark auf dem Laptop (für Netzwerkmitschnitte beim Reverse Engineering der Steckdose).

**Personal/Rollen:** Das Projekt wurde eigenständig vom Auszubildenden durchgeführt. Der Ausbilder stand als Berater zur Verfügung (z.B. für Abnahme der Planung und Zwischendemonstrationen), griff aber nicht operativ ein. Die Abnahme erfolgte durch den fiktiven Auftraggeber (z.B. Abteilungsleiter IT), der zugleich als Betreuer fungierte.

**Risikoanalyse:** Bereits in der Planungsphase wurden potenzielle Risiken und passende Gegenmaßnahmen identifiziert:

* *Risikofaktor Smart-Plug-Steuerung:* Es war unsicher, ob die Tapo P110 ohne Internetanbindung steuerbar ist, da der Hersteller keine lokale API dokumentiert. **Gegenmaßnahme:** Frühzeitiges Reverse Engineering und Recherche nach Community-Projekten. Tatsächlich fand sich heraus, dass nach initialer Einrichtung der Steckdose via Tapo-App und dem Verhindern des Internetzugangs die Steuerung lokal mittels verschlüsselter HTTP-Pakete möglich ist. Hierfür war es nötig, den Authentifizierungsprozess der Steckdose nachzuahmen (Token-Generierung). Im Worst Case stand als Alternativplan bereit, auf eine  **TP-Link Kasa HS100** -Serie Steckdose auszuweichen, die eine offene lokale API besitzt – dies wäre jedoch mit Verzicht auf Energie-Monitoring einhergegangen.
* *Risikofaktor Offline-Betrieb:* Ohne Internet stehen keine Cloud-Dienste zur Verfügung. Falls das System dennoch unerwartet externe Abhängigkeiten benötigt (z.B. NTP für Zeit, CDNs für Bibliotheken), könnte dies zu Problemen führen. **Gegenmaßnahme:** Alle erforderlichen Ressourcen wurden im Vorfeld identifiziert und lokal bereitgestellt. Für die Zeit synchronisation im Netzwerk wurde ein lokaler NTP-Server eingerichtet, damit z.B. die Smart-Steckdose beim Start die Uhrzeit erhält (einige Geräte verweigern sonst Befehle). Die Raspberry Pis fungieren als Zeitserver im Netz, wodurch die Offline-Zeitbasis gesichert war.
* *Risikofaktor Sicherheit:* Obwohl das Netzwerk isoliert ist, bestehen interne Angriffsflächen (z.B. ein Gast könnte versuchen, per direkten API-Aufruf die Steckdose zu schalten). **Gegenmaßnahme:** Umsetzung eines strikten Rechtemodells im Backend – die relevanten API-Routen prüfen die Rolle (nur Admin darf Freigaben erteilen oder Steckdose schalten). Zudem wurden Firewall-Regeln am Raspberry-Pi-AP gesetzt, um nur die notwendigen Ports zum Backend zuzulassen (z.B. Port 443 für HTTPS, ggf. TCP-Port der Steckdose, alles andere geblockt). Die selbstsignierten Zertifikate könnten ein Risiko von *Man-in-the-Middle* vermindern, aber erfordern, dass die Clients sie als vertrauenswürdig einordnen. Hier wurde für die genutzten Geräte (Kiosk-Browser, Admin-Laptop) das Zertifikat vorab importiert.
* *Risikofaktor Zeitplan:* Die Implementierung unbekannter Komponenten (Steckdosen-API, Frontend-Docker) könnte mehr Zeit in Anspruch nehmen als vorgesehen. **Gegenmaßnahme:** Puffer im Zeitplan (etwa 10–15% der Gesamtzeit) und Fokussierung auf Kernfunktionalität. Auf optionale Features (z.B. ausgefeilte Statistiken, Druckdatei-Upload) wurde verzichtet, falls die Zeit knapp würde. Tatsächlich konnten alle Muss-Anforderungen im vorgesehenen Zeitrahmen umgesetzt werden, optionale Erweiterungen blieben ausgelagert.
* *Risikofaktor Hardwareausfall:* Raspberry Pis oder Steckdose könnten defekt sein. **Gegenmaßnahme:** Bereithalten von Ersatzhardware (ein zusätzlicher Raspberry Pi, Ersatz-SD-Karten sowie eine alternative WLAN-Steckdose zum Testen). Während der Entwicklung trat kein Hardwaredefekt auf; lediglich ein SD-Karten-Rewrite war einmal nötig, was durch regelmäßige Backups der Konfiguration abgesichert war.

Mit dieser umfassenden Planung im Rücken wurde das Projekt gestartet. In der nächsten Sektion wird die praktische **Durchführung und Umsetzung** im Detail geschildert.

## Durchführung und Auftragsbearbeitung

### 3.1 Aufbau der Infrastruktur und Netzwerkkonfiguration

Die Implementierungsphase begann mit dem Aufsetzen der hardwareseitigen Infrastruktur. Zunächst wurden die beiden Raspberry Pi mit dem aktuellen Raspberry Pi OS Lite installiert und grundlegend konfiguriert. Beide Systeme erhielten statische IP-Adressen im vorgesehenen Subnetz `192.168.0.0/24` gemäß Planung: der Backend-Pi (im Folgenden *Server-Pi* genannt) die IP `192.168.0.105`, der Frontend/Kiosk-Pi (im Folgenden  *Kiosk-Pi* ) die IP `192.168.0.109` auf der LAN-Schnittstelle.

**LAN-Backend:** Der Server-Pi wurde per Ethernet an den Switch im Offline-Netz angeschlossen. In der `/etc/dhcpcd.conf` wurde die statische IP samt Subnetzmaske (255.255.255.0) und Gateway (sofern ein dedizierter Router existiert, ansonsten kein Gateway) eingetragen. Da kein Internetzugang erforderlich war, wurde als DNS-Server eine interne IP (der Kiosk-Pi) konfiguriert, da dieser später DNS-Anfragen für das WLAN handhabt. Der Server-Pi wurde mit Hostname `myp-backend` versehen, um ihn im Netz einfacher identifizieren zu können.

**WLAN-Frontend:** Der Kiosk-Pi übernahm die Rolle eines WLAN-Access-Points für Gäste. Hierfür wurde ein separates WLAN-Netz konfiguriert, SSID z.B. „MYP-Print“. Dieses WLAN läuft auf einer eigenen Netzadresse (geplant war `192.168.1.0/24`), um Gäste vom LAN zu trennen. Auf dem Kiosk-Pi wurde **hostapd** installiert und so eingerichtet, dass das integrierte WLAN-Modul im Access-Point-Modus arbeitet (WPA2-verschlüsseltes WLAN, vorab bekannt gegebener WLAN-Schlüssel für Gäste). Parallel dazu stellt **dnsmasq** auf dem Kiosk-Pi DHCP- und DNS-Dienste für das WLAN bereit, sodass verbundene Clients automatisch eine IP (z.B. `192.168.1.100` aufwärts) erhalten und Namensauflösung für definierte Hosts funktioniert. Der Kiosk-Pi selbst erhielt auf seiner WLAN-Schnittstelle (wlan0) die feste IP `192.168.1.1` als Gateway-Adresse für die WLAN-Clients.

**Routing zwischen WLAN und LAN:** Um den Gästen den Zugriff auf den Druckerserver (Backend-Pi) zu ermöglichen, wurde auf dem Kiosk-Pi IP-Routing aktiviert. In der Datei `/etc/sysctl.conf` wurde `net.ipv4.ip_forward=1` gesetzt und übernommen. Mithilfe von **iptables** wurden dann gezielte Regeln definiert: Zum einen wurde ein Masquerading (SNAT) für Verbindungen vom WLAN ins LAN eingerichtet (`iptables -t nat -A POSTROUTING -s 192.168.1.0/24 -o eth0 -j MASQUERADE`). Dadurch treten WLAN-Clients nach außen mit der IP des Kiosk-Pi im LAN (`192.168.0.109`) auf, was die Kommunikation vereinfacht und keine speziellen Routen auf dem Backend-Pi erfordert. Zum anderen wurden Filterregeln etabliert, die den Traffic einschränken: Erlaubt sind nur Verbindungen vom WLAN-Subnetz zur Backend-IP auf den Ports 443 (HTTPS für die Web-API/UI) und 123 (NTP, siehe unten) sowie DNS-Anfragen an den Kiosk-Pi. Alle anderen Verbindungsversuche ins LAN werden verworfen. Somit konnte ein Gast zwar den Webdienst des MYP-Servers erreichen, aber keine anderen (evtl. vorhandenen) Geräte im LAN scannen oder ansprechen. Dieses Routing- und Firewall-Setup wurde ausführlich getestet, bevor fortgefahren wurde, um sicherzustellen, dass das Netzabschottungskonzept wie vorgesehen greift.

**Zeitserver und Steckdosen-Einbindung ins Netz:** Eine besondere Anforderung war, dass die TP-Link Tapo P110 Steckdose im Offline-Betrieb funktioniert. Tests zeigten, dass die Steckdose nach einem Neustart versucht, einen Zeitserver (NTP) zu kontaktieren, da sie sonst Befehle verweigert (aus Sicherheitsgründen benötigt das Gerät offenbar eine aktuelle Uhrzeit). Daher wurde der Kiosk-Pi so konfiguriert, dass er Anfragen an `time.google.com` oder `pool.ntp.org` (die von der Steckdose per DNS angefragt wurden) lokal beantwortet. Via dnsmasq wurde eine DNS-Weiterleitung eingerichtet, die z.B. *pool.ntp.org* auf die IP des Kiosk-Pi zeigt. Dort lief der Dienst **chrony** als NTP-Server und lieferte der Steckdose die Uhrzeit. Nach dieser Anpassung ließ sich die Steckdose vollständig offline steuern. Die Steckdose selbst wurde ins gleiche LAN integriert: Sie bekam per DHCP (konfiguriert im Router oder per reserviertem Lease im Kiosk-Pi, falls dieser auch DHCP fürs LAN übernahm) die IP `192.168.0.110` und wurde unter dem Hostnamen `druckersteckdose` bekannt gemacht. Der Backend-Pi benötigt diese IP, um Schaltbefehle an die Steckdose zu senden.

**SSL/TLS-Konfiguration:** Parallel zur Netzwerkeinrichtung wurde das **SSL-Zertifikat** erzeugt. Da keine offizielle Zertifizierungsstelle im Offline-Netz verwendet werden kann, wurde ein selbstsigniertes Zertifikat erstellt. Mit OpenSSL generierten wir ein eigenes Root-CA-Zertifikat und einen privaten Schlüssel. Dieses CA-Zertifikat wurde dann benutzt, um ein Serverzertifikat für den Backend-Pi (`myp-backend`) auszustellen. So entstand ein Zertifikatspaar (CA und Server), das auf dem Backend-Pi in die Flask-Konfiguration eingebunden wurde. Der Flask-Server wurde so konfiguriert, dass er HTTPS auf Port 443 bedient und das Zertifikat + Private Key lädt. Das CA-Zertifikat wurde auf den Client-Geräten importiert (z.B. im Browser des Kiosk-Pi sowie im Firefox des Admin-Laptops), damit die Zertifikate als vertrauenswürdig anerkannt werden und keine Warnmeldungen die Nutzer verunsichern. Damit waren alle Voraussetzungen geschaffen, das Backend- und Frontend-System sicher im lokalen Netz zu betreiben.

### 3.2 Implementierung des Flask-Backends (Server)

Nach der Infrastrukturvorbereitung wurde die Backend-Software entwickelt. Zunächst wurde eine Grundstruktur für die Flask-Anwendung angelegt. Das Projekt wurde in einem Git-Repository versioniert, was schrittweise Commits für einzelne Funktionseinheiten ermöglichte.

**Datenbankmodell:** Vor dem Coding wurde das **Datenbankschema** entworfen. Aufgrund der Einfachheit der Anforderungen genügte SQLite als eingebettete Datenbank; diese benötigt keinen separaten Serverdienst und speichert die Daten in einer Datei (`myp.db`) auf dem Backend-Pi. Das Schema umfasst u.a. folgende Tabellen:

* `benutzer`: Enthält Benutzerkonten. Wichtige Felder: `benutzer_id` (Primärschlüssel), `benutzername` (Login-Name, eindeutig), `passwort_hash` (verschlüsselter Hash des Passworts), `rolle` (ENUM mit Werten „Admin“ oder „Gast“). Für die Passwort-Hashes wurde die sichere Hash-Funktion PBKDF2 (über die Flask-Bibliothek Werkzeug) genutzt, um Passwörter nicht im Klartext zu speichern.
* `anfrage`: Enthält Druckanfragen. Felder: `anfrage_id`, `benutzer_id` (Referenz auf den anfragenden Nutzer), `zeitstempel_anfrage` (Erstellungszeitpunkt), `gewünschter_zeitpunkt` (vom Nutzer gewünschtes Druckdatum/Uhrzeit, falls angegeben), `status` (Status der Anfrage: „offen“, „genehmigt“, „abgelehnt“, „gedruckt“ etc.), `otp_code` (der für eine genehmigte Anfrage generierte Code, initial null). Zusätzlich ggf. ein Feld `dateiname` oder `beschreibung` für Angaben zum Druckauftrag.
* `reservierung`: Diese Tabelle wurde eingeführt, falls Zeitfenster reserviert werden. Sie enthält z.B. `startzeit`, `endzeit`, `anfrage_id` (Referenz auf Anfrage). Alternativ hätte man Start/Endzeit direkt in `anfrage` speichern können; das Design wurde modular gehalten, um evtl. mehrere Zeitfenster oder Änderungen zu erlauben.
* `ereignislog`: Für Verwaltungs- und Debugzwecke werden hier wichtige Ereignisse protokolliert (z.B. „Anfrage X erstellt“, „Admin Y hat Anfrage X genehmigt“ mit Zeitstempel). Dies erleichtert später die Nachvollziehbarkeit und kann im Admin-Interface als Verlauf angezeigt werden.

Das Datenmodell wurde mit Hilfe von **SQLAlchemy** (ein ORM für Python) erstellt, was die Definition der Tabellen als Klassen ermöglichte. Alternativ stand die Nutzung von raw-SQL/SQLite im Raum; aus Zeitgründen und aufgrund einfacher Anforderungen wurde schlussendlich teils raw SQL verwendet (direktes Ausführen von `CREATE TABLE` Statements beim Erststart), um die Abhängigkeiten schlank zu halten.

**API-Design und Routen:** Das Flask-Backend wurde so gestaltet, dass es sowohl **HTML-Seiten** (für die Jinja2-Fallback-Oberfläche) als auch **REST-API-Endpunkte** liefert. Hierfür wurden Blueprints in Flask eingesetzt, um die Logik nach Modul zu trennen:

* **Authentifizierungsrouten:** `/login` (GET/POST) für das Login-Formular bzw. API-Login, `/logout` (GET) zum Abmelden. Flask-Login übernahm das Session-Management bei HTML-Aufrufen. Für API-Zugriffe (vom React-Frontend) wurde eine Token-basierte Authentifizierung implementiert: Nach erfolgreichem Login erhält der Client ein zeitlich begrenztes JWT (JSON Web Token), das bei nachfolgenden API-Aufrufen im Header mitgeschickt wird. Dies ersparte zustandsbehaftete Sessions im reinen API-Betrieb. Im Kiosk/HTML-Betrieb hingegen wurden klassische Sessions/Cookies genutzt, um Aufwand zu reduzieren.
* **Benutzerverwaltung:** `/api/benutzer` (nur für Admin, z.B. GET Liste aller Nutzer, POST zum Anlegen eines neuen Nutzers). Diese Routen wurden primär für eventuelle Erweiterungen vorbereitet; im Minimum existierte ein default Admin-Account und einige Gast-Accounts, welche über die Datenbank oder Konfigurationsdatei initial angelegt wurden.
* **Anfragen-Management:**
  * `POST /api/anfragen`: Wird von einem Gast aufgerufen, um eine neue Druckanfrage anzulegen. Die Request-Daten (z.B. gewünschter Zeitraum, Beschreibung) werden entgegen genommen, validiert (z.B. Pflichtfelder ausgefüllt, Zeit in Zukunft, Nutzer hat nicht bereits eine offene Anfrage) und in der Datenbank als Status „offen“ gespeichert. Das System kann optional sofort prüfen, ob der gewünschte Zeitraum frei ist (Abgleich mit bestehenden genehmigten Reservierungen) – ein entsprechender Konflikt würde dem Benutzer gemeldet.
  * `GET /api/anfragen` (Admin): Liefert die Liste der offenen (und/oder aller) Anfragen mit ihren Details, damit der Administrator sie anzeigen kann.
  * `PUT /api/anfragen/<id>/entscheidung`: Nimmt eine Entscheidung für Anfrage `<id>` entgegen. Diese Route erwartet im Payload z.B. `{"aktion": "genehmigen"}` oder `{"aktion": "ablehnen", "grund": "..."}`. Bei Genehmigung erzeugt der Server folgendes: Er generiert einen eindeutigen  **OTP-Code** , bestehend z.B. aus 6 Ziffern, mittels einer Kryptografie-Funktion (um ausreichende Zufälligkeit zu gewährleisten). Dieser Code wird in der Datenbank in der betreffenden Anfrage gespeichert und der Status der Anfrage auf „genehmigt“ gesetzt. Außerdem wird ein entsprechender Termin in der `reservierung`-Tabelle vermerkt (Start-/Endzeit, basierend auf gewünschtem Zeitraum oder aktuellen Zeitpunkt plus Puffer). Bei Ablehnung wird der Status auf „abgelehnt“ gesetzt und der angegebene Grund gespeichert (optional). Nach beiden Aktionen könnte das Benachrichtigungssystem greifen (siehe unten).
  * `GET /api/anfragen/offen` (Admin): Optionaler Endpunkt, der nur die offenen Anfragen zählt oder zurückgibt, um z.B. im UI eine „neue Anfrage“-Benachrichtigung anzeigen zu können.
* **Kalender/Reservierungsdaten:** `GET /api/reservierungen` (authentifiziert: Gast sieht eigene und freie Slots, Admin sieht alle). Dieser Endpunkt liefert die genehmigten Drucktermine, formatiert für die Nutzung in FullCalendar (JSON mit Feldern wie Title, Start, End, evtl. color etc.). Gäste bekommen evtl. nur einen Teil der Informationen (z.B. als „belegt“ markierte Zeiten ohne fremde Nutzernamen, aus Datenschutzgründen).
* **Steuerungsfunktionen (Smart Plug):**
  * `POST /api/steckdose/schalten` (Admin oder intern): Dieser Endpunkt wird genutzt, um die Steckdose an- oder auszuschalten. Im Normalfall wird er vom System selbst aufgerufen, nicht direkt vom Benutzer: Wenn ein Gast seinen OTP-Code eingibt (über UI), ruft das Frontend die API z.B. `POST /api/auftrag/<id>/start` auf. Dieser wiederum prüft den Code, und wenn korrekt, schaltet er über die Steckdosen-API den Strom ein. Dennoch wurde die Steckdosen-Schaltfunktion gekapselt, um auch manuelle Steuerung zu erlauben (z.B. Administrator-Notfallknopf "Steckdose aus" bei Problemen).

Sämtliche API-Routen prüfen zunächst die Berechtigung. Dazu wurde eine Middleware bzw. Decorator in Flask implementiert, der bei jedem API-Request das JWT oder die Session überprüft und die Rolle aus der Nutzerinfo liest. Ein unerlaubter Zugriff (z.B. Gast ruft Admin-Route auf oder fehlende Authentifizierung) wird mit HTTP 401/403 beantwortet. In der Fallback-HTML-Oberfläche wurde ähnliches über Flask-Login accomplished, indem sensible Seiten @login_required und eine Rollenprüfung enthalten.

**Implementierung der Backend-Logik:** Nachdem die Routen definiert waren, wurden die dahinterliegenden Funktionen implementiert:

* Die Login-Funktion vergleicht den eingegebenen Usernamen/Passwort-Hash mit der DB. Bei Erfolg erstellt sie entweder eine Session (HTML) oder ein JWT (API) mit den nötigen Claims (BenutzerID, Rolle, Gültigkeit z.B. 8 Stunden).
* Die Anfrage-Erstellen-Funktion erzeugt einen neuen Datensatz, initialisiert den Status „offen“ und loggt das Ereignis ("Nutzer X hat Anfrage Y gestellt um..."). Falls ein gewünschter Zeitbereich angegeben ist, prüft die Logik per SQL-Abfrage, ob dieser mit bereits genehmigten Aufträgen überlappt. Falls ja, wird die Anfrage entweder abgelehnt oder markiert (je nach Policy: hier entschieden wir uns, dem Nutzer direkt mitzuteilen „Zeitraum belegt“ und ihn einen anderen wählen zu lassen, bevor die Anfrage gespeichert wird).
* Die Anfrage-Entscheidungs-Funktion bei Genehmigung verwendet Python's `random.SystemRandom` oder eine sichere Zufallsfunktion, um einen 6-stelligen Zahlencode zu generieren. Dieser Code wird dem Nutzer später präsentiert. Zudem setzt der Code intern einen Timer/Deadline: Ein genehmigter Auftrag muss innerhalb z.B. 15 Minuten gestartet werden, sonst verfällt er. Diese Frist wurde in der Datenbank als Feld (gültig_bis) notiert. Ein geplanter Druck zu einer späteren Zeit (z.B. in 2 Stunden) würde bedeuten, dass der OTP-Code erst kurz vor Start freigegeben wird – der Einfachheit halber entschied man sich hier dafür, den Code sofort zu zeigen, aber den Drucker nicht vor dem reservierten Startzeitpunkt zu aktivieren. Das heißt, auch wenn der Nutzer den Code früher eingibt, wartet das System bis zur Startzeit, bevor es die Steckdose schaltet. Dies wurde im Code so gelöst, dass der `/start`-Endpunkt bei Eingabe prüft: aktuelle Zeit >= reservierte Startzeit. Falls zu früh, gibt er eine Meldung zurück „Bitte zum vorgesehenen Zeitpunkt erneut versuchen“.
* Die OTP-Prüfung und Steckdosen-Schaltung sind sicherheitskritisch. Beim Aufruf `POST /api/auftrag/<id>/start` werden AuftragID und OTP-Code entgegengenommen. Der Server gleicht den Code gegen die DB (für Auftrag id) ab und prüft, ob: a) der Status genehmigt und noch nicht gedruckt ist, b) der Code übereinstimmt, c) die aktuelle Zeit innerhalb des erlaubten Fensters liegt. Nur wenn alles passt, erfolgt die Aktion: es wird der Befehl zum Einschalten der Steckdose abgesetzt (siehe nächster Abschnitt zur Umsetzung) und der Status der Anfrage auf „gedruckt“ (bzw. „in Bearbeitung“ und später „abgeschlossen“) gesetzt. Zusätzlich startet ein Timer-Thread im Backend, der nach einer definierten Druckdauer (z.B. 5 Minuten oder sobald der Nutzer im UI meldet „fertig“) die Steckdose automatisch wieder ausschaltet. Dadurch wird verhindert, dass der Drucker länger als nötig an bleibt. Alle diese Aktionen werden im Ereignislog festgehalten. Bei falschem Code oder abgelaufener Zeit liefert der Endpunkt einen Fehler zurück, den das Frontend als Meldung anzeigen kann („Code ungültig“ oder „Zeitfenster abgelaufen“). Nach dreimaliger Falscheingabe könnte das System den Auftrag sperren – diese Option wurde angedacht, aber im ersten Wurf nicht umgesetzt, da der Code ohnehin in kurzer Zeit verfällt.

**Benachrichtigungssystem:** Um Administratoren zeitnah über neue Anfragen zu informieren, wurde ein einfaches Polling im Admin-Frontend umgesetzt: Alle 30 Sekunden fragt der Browser des Admins an `/api/anfragen/offen` an, um zu sehen, ob neue Aufträge hinzugekommen sind, und zeigt gegebenenfalls eine visuelle Markierung oder spielt einen Sound ab. Alternativ wurde überlegt, WebSockets zu nutzen, um Push-Benachrichtigungen in Echtzeit zu ermöglichen. Aus Einfachheitsgründen (Offline-Betrieb, bei dem keine Skalierungsprobleme zu erwarten sind) wurde jedoch auf WebSockets verzichtet und Polling gewählt. Für den Gast wird ähnlich verfahren: Nach dem Stellen einer Anfrage bleibt der Browser auf einer Statusseite, die periodisch den Status der Anfrage abfragt (`/api/anfragen/<id>`). Sobald der Status auf genehmigt/abgelehnt wechselt, aktualisiert sich die Anzeige (z.B. „Ihre Anfrage wurde genehmigt – Ihr Code lautet 123456“). Im Kiosk-Modus der Fallback-UI wurde das Polling integriert, um z.B. direkt nach Login eines Admin eine Benachrichtigung bei neuen Anfragen einzublenden.

**Jinja2-Fallback-UI:** Parallel zur API-Entwicklung wurden grundlegende HTML-Seiten mit Jinja2-Templates erstellt, um das System unabhängig vom React-Frontend nutzbar zu machen. Dies war sowohl zur Absicherung gedacht (falls der Docker-Container mit dem modernen Frontend ausfällt oder der Kiosk-Browser Probleme mit moderner Webapp hat) als auch zur einfachen direkten Nutzung am Kiosk-Pi. Die Fallback-Oberfläche umfasst z.B. folgende Seiten:

* Login-Seite (`login.html`): Einfache Maske zur Anmeldung, nutzt Flask-Login.
* Gast-Startseite (`gast_index.html`): Formular zur Eingabe einer neuen Druckanfrage (Felder: Termin, Beschreibung etc.) und Anzeige der eigenen offenen/früheren Anfragen. Nach Absenden wird entweder eine Bestätigung angezeigt („Anfrage eingereicht“) mit Hinweis auf Wartezeit.
* Gast-Statusseite (`gast_status.html`): Zeigt den aktuellen Status der Anfrage an, insbesondere bei genehmigt den OTP-Code groß und gut lesbar. Im Kiosk-Flow würde diese Seite dem Nutzer präsentiert werden, ggf. mit einer Schaltfläche „Druck starten“, die zur Codeeingabe auffordert (wenn der Code vom System generiert und dem Nutzer aber noch nicht automatisch angezeigt werden soll, was hier jedoch der Fall war – er sieht seinen Code ohnehin).
* Admin-Übersichtsseite (`admin_dashboard.html`): Listet alle offenen Anfragen tabellarisch mit Details (Nutzer, Zeitpunkt, ggf. Dokumentinfo). Hier kann der Admin per Button „genehmigen“ oder „ablehnen“ klicken. Dies ruft intern eine JavaScript-Funktion auf, die per AJAX die entsprechende API (PUT Entscheidung) triggert. Alternativ bei deaktiviertem JS könnte es über separate Bestätigungsseiten laufen – aber wir setzten auf Ajax für bessere Usability. Ferner zeigt die Admin-Seite alle kommenden Reservierungen (Kalenderübersicht) und den Verlauf (log) der letzten Aktionen.
* Admin-Benutzerverwaltung (`admin_users.html`): Ermöglicht das Anlegen neuer Benutzer oder Ändern von Passwörtern. Diese Seite war rudimentär, da Benutzer meist vordefiniert werden.
* Kiosk-OTP-Eingabe (`kiosk_otp.html`): Eine spezielle Seite, die im Kiosk-Modus genutzt wird, um einen OTP-Code einzugeben und den Druckvorgang zu starten. Hier sieht der Nutzer z.B. ein Nummernfeld zur Eingabe des 6-stelligen Codes. Diese Seite ist so gestaltet, dass sie auch ohne Tastatur auf einem Touchscreen bedient werden kann (digitale On-Screen-Nummernblock). Wenn der Code eingegeben und abgesendet wird, erfolgt im Hintergrund ein Aufruf der Start-API; bei Erfolg erscheint „Drucker wird jetzt aktiviert – bitte drucken Sie Ihr Dokument“ und bei Misserfolg eine Fehlermeldung.

Diese Jinja2-Seiten wurden mit einfachem CSS gestaltet, um zumindest grundlegende Responsivität und ansprechende Optik zu bieten. Dabei wurde kein externes CSS genutzt, sondern das nötigste (Fonts, Layout) direkt eingebunden. Für komplexere Elemente wie Kalender oder Modal-Dialogs wurde im Fallback-UI verzichtet – diese stehen nur im modernen Frontend zur Verfügung. Somit bleibt die Fallback-Oberfläche simpel, aber robust.

Nach Abschluss der Backend-Entwicklung (API und Fallback-UI) wurden initiale Komponententests durchgeführt. Beispielsweise wurden die API-Endpunkte mit *cURL* und einem REST-Client durchgespielt (für Login, Anfrage erstellen, genehmigen etc.), um sicherzustellen, dass die Logik korrekt arbeitet, bevor die komplexe Steckdosenansteuerung und das Frontend hinzukamen.

### 3.3 Integration der Smart-Plug-Steuerung (TP-Link Tapo P110)

Ein zentrales technisch anspruchsvolles Element war die lokale Ansteuerung der TP-Link Tapo P110 WLAN-Steckdose. Da TP-Link offiziell vorsieht, dass die Tapo-Geräte über eine Cloud/App gesteuert werden, gab es keine offizielle lokale API-Dokumentation. Daher wurden zwei Ansätze kombiniert: Recherche nach bestehenden Lösungen und eigenständige Paket-Analyse.

**Recherche und Vorbereitung:** Zunächst wurde geprüft, ob es Open-Source-Projekte gibt, die die Tapo-Geräte lokal steuern können. Es wurde ein Python-Modul namens **PyP100** gefunden, das grundsätzlich die Tapo P100/P110 ansprechen kann. Ein Blick in den Quellcode und Dokumentation zeigte, dass die Steckdose über HTTP/HTTPS auf Port 443 angesprochen wird und JSON-Nachrichten annimmt. Die Kommunikation ist jedoch verschlüsselt: Zunächst muss ein Handshake erfolgen, bei dem man sich mit Tapo-Cloud-Zugangsdaten authentifiziert (E-Mail und Passwort, die in der Tapo-App registriert wurden), daraus generiert die Steckdose oder Cloud ein Token und einen Session-Key, mit dem nachfolgende Befehle symmetrisch verschlüsselt übertragen werden. Für das Offline-Szenario bedeutete das: Die Steckdose wurde initial via Tapo-App in Betrieb genommen (einmalig, um sie ins WLAN zu bringen und dem TP-Link-Account zuzuordnen), danach der Internetzugang blockiert. Im lokalen Netz akzeptiert die Steckdose dann Verbindungen, wenn man den richtigen Authentifizierungsprozess nachbildet.

**Reverse Engineering mit Wireshark/scapy:** Um den Ablauf exakt zu verstehen, wurde ein Testaufbau gemacht: Die Steckdose wurde in ein Test-WLAN eingebunden, der Entwicklungs-Laptop mit Wireshark lauschte auf dem WLAN-Interface. Mit der offiziellen Tapo-App (auf einem Smartphone, verbunden mit selbem WLAN) wurden Ein- und Ausschalten der Steckdose durchgeführt. Wireshark konnte die Pakete mitschneiden. Da TLS (HTTPS) verwendet wird, sah man nicht den Klartext, aber man konnte das Verbindungsmuster erkennen: Zunächst eine TLS-Handshake mit dem TP-Link Cloud-Server, dann (bei lokalem Befehl in gleicher Netzwerk?) interessanterweise auch Traffic an die lokale IP der Steckdose. Nach Recherche wurde klar: Die Tapo-App kommuniziert bei Steuerbefehlen direkt mit der Steckdose (Lokal), aber benötigt zuvor ein Token von der Cloud (daher initial Cloud-Aufruf). Für Offline-Betrieb musste dieser Mechanismus umgangen werden.

Mittels scapy (einem Python-Paket zur Paketanalyse und -manipulation) und der Analyse des PyP100 Moduls wurde der folgende Weg implementiert:

1. **Lokale Authentifizierung:** Das Backend sendet an die Steckdose ein HTTPS-POST auf `/app` mit einem JSON, das die Anmeldeinformationen (verschlüsselt) enthält. Die Verschlüsselung besteht aus RSA (öffentlicher Schlüssel der Steckdose) für den Initial-Handshake, danach AES für Folgebefehle. Im Projekt wurde die Crypto-Bibliothek PyCryptodome genutzt, um diese Verschlüsselung nachzustellen. Das RSA-Public-Key der Steckdose wurde aus einem initialen Info-Paket entnommen (die Steckdose liefert es bei einem unverschlüsselten Info-Request). Anschließend wird Benutzername/Passwort (TP-Link Account) damit verschlüsselt und gesendet.
2. **Token-Erhalt:** Wenn die Credentials stimmen (die Steckdose hat sie lokal cached von der Erstinstallation), liefert sie ein Token zurück. Dieser Token ist eine Art Session-ID für lokale Befehle. Zusätzlich teilt die Steckdose einen Session-Schlüssel (AES-Key) mit, der für weitere Kommunikation genutzt wird.
3. **Befehle senden:** Mit dem erhaltenen Token wird nun der eigentliche Schaltbefehl abgesetzt. Dazu wird wiederum eine JSON-Struktur definiert, z.B. `{"method": "set_device_info", "params": {"device_on": true}}` um die Steckdose einzuschalten. Diese JSON wird mit dem Session-AES-Key verschlüsselt (typischerweise in Base64 kodiert übertragen). Der Backend-Server ruft also per HTTPS (unter Verwendung z.B. der Python-Requests-Bibliothek mit entspanntem Zertifikatscheck, da Steckdose ein selbstsign. Zert hat) die URL `https://druckersteckdose/app?token=<Token>` auf, schickt den verschlüsselten Payload. Die Steckdose antwortet mit einem JSON, das Erfolg oder Fehler meldet (ebenfalls verschlüsselt, dann vom Backend wieder zu entschlüsseln).
4. **Implementierung im Code:** Im Flask-Backend wurde diese Logik in einem separaten Modul `tapo_control.py` gekapselt. Um nicht jedes Mal neu authentifizieren zu müssen (relativ zeitaufwändig, ca. 1-2 Sekunden), wurde ein Token-Cache implementiert: Beim ersten Schaltversuch authentifiziert sich das Backend bei der Steckdose und behält den Token und Key im Speicher für die Laufzeit. Solange die Steckdose nicht neu startet oder der Token abläuft, können direkt Schaltbefehle gesendet werden. Sollte ein Befehl fehlschlagen (z.B. Token ungültig), fängt das Backend dies ab, führt erneut den Auth-Schritt aus und wiederholt den Befehl. So ist hohe Robustheit gewährleistet.
5. **Fehlerbehandlung:** Falls die Steckdose nicht erreichbar ist (z.B. Netzwerkproblem), gibt das System dem Nutzer/Admin sinnvolle Fehlermeldungen („Steckdose nicht erreichbar. Bitte prüfen Sie die Netzwerkverbindung.“). Diese Situation trat im Test z.B. auf, wenn die Steckdose stromlos war oder sich neu verband – was in der Praxis aber selten sein sollte, solange sie dauerhaft eingesteckt bleibt.

Die Integration der Smart-Plug-Steuerung war nach erfolgreichen Tests abgeschlossen. Tests erfolgten durch direkte Aufrufe aus dem Python-Modul sowie aus der Anwendung heraus: Ein Administrator konnte über die Admin-Weboberfläche die Steckdose manuell schalten (für Testzwecke wurde ein „An/Aus“-Toggle implementiert, nur sichtbar für Admin, um unabhängig vom OTP-Prozess die Funktion zu prüfen). Die Reaktionszeit der Steckdose im lokalen Netz lag bei unter einer Sekunde – beim Klick auf „Ein“ hörte man fast augenblicklich das Klicken des Relais. Dies bestätigte die erfolgreiche lokale Steuerbarkeit.

### 3.4 Frontend-Integration und Kiosk-Modus

Während das Hauptaugenmerk des Prüflings auf Backend und Netzwerk lag, musste für die Gesamtfunktion ein bedienbares Frontend vorhanden sein. Dieses gliederte sich in zwei Teile: das moderne Web-Frontend (Docker-Container mit React-App) und die bereits erwähnte Fallback-UI für den Kiosk.

**Docker-basiertes React-Frontend:** Ein Kollege im Ausbildungsbetrieb hatte parallel eine auf **Next.js/React** basierende Anwendung erstellt, die als Frontend dienen konnte. Dieses Frontend wurde so konzipiert, dass es alle API-Funktionen des MYP-Backends nutzt. Es bietet ein ansprechenderes UI mit dem Design-Framework *shadcn/UI* (welches auf Tailwind CSS basiert) und umfangreiche Interaktivität. Die Anwendung lief in einem Docker-Container, was die Bereitstellung auf dem Raspberry Pi erleichterte (Isolation der Node.js-Laufzeitumgebung, einfaches Deployment via Image). Der Prüfling übernahm die Aufgabe, dieses Frontend auf dem Kiosk-Pi zu installieren und mit dem Backend zu verbinden:

* Zunächst wurde Docker Engine auf dem Raspberry Pi installiert. Dann das Frontend als Container Image gebaut (die Build-Schritte werden in einem Dockerfile definiert, inkl. Installation aller Dependencies via pnpm). Dieses Image wurde auf den Pi übertragen und gestartet. Der Container lauschte z.B. auf Port 3000 und servierte dort die Web-App.
* Die React-App war so konfiguriert, dass Aufrufe der API an den Backend-Pi geleitet wurden. Da beide auf demselben Hostnamen/Subnetz liefen, wurde z.B. die BASE_URL auf `https://myp-backend` gesetzt. Im Pi’s /etc/hosts wurde `myp-backend` auf 192.168.0.105 gemappt, sodass der Container den Backend-Server findet (oder man nutzte direkt die IP in der Konfiguration).
* Nach dem Start des Containers wurde getestet: Vom Admin-Laptop aus konnte man in der URL `https://192.168.0.109:3000` die React-App aufrufen (bzw. mit einem Port-Forward im Pi zu 80). Die App zeigte den Login-Screen, und nach Login als Admin sah man die Liste der Anfragen etc. Ebenso konnte man von einem WLAN-Client (Gast-Handy) über `http://192.168.1.1` (der Pi könnte im WLAN auch als Webserver fungieren) die App benutzen. In unserem Setup wurde erwogen, den Kiosk-Pi auch als Reverse Proxy einzusetzen: d.h. der Pi lauscht auf Port 80/443 und entscheidet, ob er die Anfrage an das React-Frontend oder das Flask-Backend weiterleitet, um CORS-/Port-Probleme zu minimieren. Aus Zeitgründen und Einfachheit wurde im Test aber meist direkt gearbeitet (z.B. React auf 3000, Flask auf 443, und das React-Frontend greift via HTTPS auf Flask-API zu).
* Die moderne Web-App bietet denselben Funktionsumfang wie die Fallback-UI, jedoch mit besserer User Experience: z.B. ein interaktiver Kalender, modale Dialoge für die Codeeingabe, Live-Updates via React state (statt Polling, wobei intern auch hier Polling/Long Polling genutzt wurde). Für die Prüfung selbst wurde primär die Funktion demonstriert; Detailunterschiede zwischen Frontend-Versionen wurden nicht vertieft, da Fokus auf dem Vernetzungsaspekt lag.

**Kiosk-Modus Betrieb:** Der Raspberry Pi Kiosk wurde so eingerichtet, dass beim Systemstart automatisch ein Browser im Vollbild die Anwendung öffnet. Dazu wurde ein leichtgewichtiges X-Window-System installiert und **Chromium** als Browser. In der Datei `/etc/xdg/lxsession/LXDE-pi/autostart` wurde der Autostart des Browsers mit folgenden Optionen konfiguriert:

```
@chromium-browser --kiosk --app=https://myp-backend/kiosk_otp --ignore-certificate-errors --disableScreensaver
```

Diese Zeile bewirkt, dass Chromium ohne Fensterelemente (`--kiosk`) direkt die Kiosk-OTP-Seite der Flask-Fallback-UI lädt. Die Option `--ignore-certificate-errors` war nötig, da unser selbstsigniertes Zertifikat sonst eine Warnung erzeugt (alternativ hätte man das Zertifikat in Chromium hinterlegen können). `--disableScreensaver` verhindert, dass der Bildschirm in den Energiesparmodus geht.

Beim Booten des Kiosk-Pi loggt sich ein dedizierter `kiosk`-Benutzer automatisch ein (eingerichtet via `raspi-config` Autologin) und startet die grafische Session mit obiger Autostart. Somit steht binnen weniger Sekunden nach Einschalten ein Terminal bereit, auf dem entweder der React-Frontend (wenn man die URL dahingehend ändert) oder die Fallback-UI angezeigt wird. In unserem Fall entschieden wir uns im Kiosk-Browser für die Fallback-OTP-Eingabeseite, weil die React-App für Touchbedienung nicht optimiert war. Stattdessen sah der Workflow so aus: Ein Gast stellt eine Anfrage entweder am Kiosk (über die Fallback-Gast-Seite) oder mit eigenem Gerät. Der Admin genehmigt am Admin-Interface. Dann geht der Gast zum Drucker/Kiosk, dort ist bereits die OTP-Eingabeseite offen (sie zeigt z.B. „Bitte Code eingeben“). Der Gast gibt den erhaltenen Code ein, drückt auf „Start“. Die Seite ruft die API auf und bei Erfolg wechselt der Bildschirm zu „Drucker aktiv – bitte Dokument drucken...“ und vielleicht einem Hinweis zum Drucken (wenn z.B. ein USB-Stick verwendet werden muss, etc.). Nach Ablauf der Druckzeit oder beim nächsten Vorgang setzt sich die Seite zurück.

**Test der Kiosk-Interaktion:** Dieser Ablauf wurde praktisch getestet. Beispielszenario im Test: Gast erstellt Anfrage am Kiosk selbst (d.h. nutzt den Kiosk-Pi UI als Gast). Admin am Laptop sieht die Anfrage und genehmigt. Kiosk-Pi (Gast-Seite) erkennt Genehmigung nach dem nächsten Polling und zeigt „Ihr Code: 749201“. Gast drückt „Drucken starten“, wechselt zur OTP-Seite (bzw. ist schon dort, je nach Implementation) und gibt 749201 ein. Die Steckdose schaltet ein, Drucker druckt eine Testseite, danach wird die Steckdose automatisch wieder ausgeschaltet. Das Testprotokoll vermerkte alle Schritte als erfolgreich. Auch ein negativer Test: Gast gibt falschen Code ein -> Meldung „falscher Code“. Zweiter Versuch richtig -> klappt. Danach Versuch gleichen Code erneut -> Meldung „ungültig“ (weil schon benutzt). Die Kiosk-Lösung erwies sich als bedienfreundlich; selbst ohne persönliche Einweisung konnte ein Kollege die Codeeingabe nachvollziehen und durchführen.

### 3.5 Qualitätssicherung und Tests

Nach Fertigstellung der Implementierung wurde das Gesamtsystem einem gründlichen **Test** unterzogen, um die Erfüllung der Anforderungen sicherzustellen und Fehler zu finden. Die Tests wurden zum einen funktional (gegen die ursprünglichen Use-Cases) und zum anderen technisch (Netzwerksicherheit, Performance) durchgeführt.

**Funktionale Tests:** Es wurden verschiedene Szenarien durchgespielt:

* **Standardablauf Einzelauftrag:** Ein Gast stellt im System eine Anfrage für „jetzt sofort drucken“. Der Admin genehmigt diese umgehend. Der Gast nutzt den OTP-Code und druckt. *Erwartetes Ergebnis:* Anfrage-Status wechselt korrekt, Code wird akzeptiert, Steckdose schaltet an, Druck möglich, Steckdose schaltet nach Zeit X ab, Status wird auf „abgeschlossen“ gesetzt. *Ergebnis:* Test erfolgreich, der Druckvorgang konnte durchgeführt werden, im Admin-Interface erschien der Auftrag als erledigt.
* **Ablehnungsszenario:** Gast stellt eine Anfrage (z.B. für später am Tag). Admin lehnt ab (mit Begründung „Drucker derzeit nicht verfügbar“). *Erwartung:* Gast wird benachrichtigt, kein OTP erstellt, Drucker bleibt aus. *Ergebnis:* Test erfolgreich, Gast-Oberfläche zeigte Meldung mit Ablehnungsgrund, Anfrage verschwand aus offenen Anfragen, Steckdose blieb aus (kein Einschaltversuch).
* **Konflikt und Kalender:** Zwei Gäste wollten denselben Zeitraum reservieren (z.B. 10:00–10:15 Uhr). Gast A sendet Anfrage, Admin genehmigt. Gast B versucht kurz darauf denselben Zeitraum. *Erwartung:* System sollte zweiten Konflikt erkennen und nicht doppelt vergeben. *Ergebnis:* Der zweite Gast bekam beim Anfragestellen direkt einen Hinweis „Zeitslot bereits belegt“ und musste einen anderen Slot auswählen. Somit kam es gar nicht erst zu unlösbaren Kollisionen. Der Kalender im Admin-UI zeigte korrekt eine Reservierung um 10:00–10:15 für Gast A.
* **Timeout OTP:** Ein genehmigter Auftrag wurde absichtlich nicht eingelöst (Gast erschien nicht). *Erwartung:* Nach Ablauf des Zeitfensters verfällt der Code und Druck nicht mehr möglich. *Ergebnis:* Nach der konfigurierten Frist (hier 15 Minuten nach genehmigter Zeit) änderte das System den Status auf „verfallen“ und ein späterer Versuch, den Code doch noch einzugeben, wurde vom System abgelehnt („Zeitfenster überschritten“). Der Drucker blieb ausgeschaltet. Im Admin-Interface war die Anfrage entsprechend markiert.
* **Benutzer- und Rechteprüfung:** Versuche, ohne Login oder mit Gast-Account auf Admin-Funktionen zuzugreifen, wurden getestet (z.B. direkter API-Call auf `/api/anfragen` ohne Token, oder Aufruf der Admin-Seite als Gast). *Erwartung:* Zugriff verweigert. *Ergebnis:* Systeme reagierten korrekt mit Login-Redirect bzw. 403-Fehler, keine unbefugte Aktion war möglich. Auch ein direkter Aufruf der Steckdosen-API durch einen Client wurde blockiert durch die Firewall (Ping zur Steckdose aus WLAN ergab keine Antwort, HTTP-Aufruf aus WLAN auf Steckdose schlug fehl). Somit bestätigte sich die Sicherheitsarchitektur.
* **Mehrbenutzer-Betrieb:** Zur Sicherheit wurde auch getestet, ob mehrere Nutzer parallel das System benutzen könnten (auch wenn in Praxis vielleicht selten). Zwei unterschiedliche Gast-Accounts loggten sich auf zwei Geräten ein, stellten nacheinander Anfragen. Der Admin genehmigte beide in beliebiger Reihenfolge. *Ergebnis:* Das System konnte beide Anfragen getrennt handhaben. Codes waren unterschiedlich, jeder Gast sah nur seinen Code. Die Steckdose konnte natürlich physisch nur einen Drucker bedienen – hier wurde angenommen, dass Drucke seriell erfolgen. Falls Admin versehentlich zwei gleichzeitige Zeitfenster genehmigt hätte, wäre der zweite Druck erst nach manueller Umschaltung möglich. Aber dank der Kalenderprüfung passierte dies nicht.

**Technische Tests:**

* **Netzwerk und Performance:** Mit dem Tool *Apache Bench* (ab) wurden einfache Lasttests auf den Flask-Server durchgeführt, um zu sehen, wie viele Requests pro Sekunde verarbeitet werden können. Ergebnis: ca. 50 req/s für einen einfachen GET, was für unsere geringe Nutzerzahl völlig ausreicht. Die Latenz für einen typischen Workflow (Anfrage stellen bis OTP erhalten) lag bei wenigen Sekunden, hauptsächlich abhängig davon, wann der Admin reagiert. Die Steckdosen-Schaltzeit (<1s) war ebenfalls zufriedenstellend.
* **Systemstabilität:** Das System (besonders die Flask-App und das WLAN des Kiosk-Pi) wurde über mehrere Stunden laufen gelassen. Der Speicherverbrauch des Flask-Servers blieb stabil (kein Memory Leak beobachtet). Die CPU-Last auf dem Backend-Pi war meist unter 5% idle, Spitze 20% beim gleichzeitigem Schalten der Steckdose (wegen Kryptoberechnungen) – vernachlässigbar für den Raspberry Pi 4. Der Kiosk-Pi zeigte etwas höhere Last (Chromium Browser ~15% dauernd, Docker/Frontend ~10-20%), aber auch das war im grünen Bereich. Kein Absturz trat auf.
* **Wiederanlauf und Ausfallsicherheit:** Ein Test wurde durchgeführt, indem der Backend-Pi neu gestartet wurde, während System in Wartestellung war. Nach dem Reboot war der Flask-Dienst automatisch per Systemd gestartet und das System wieder erreichbar. Der Kiosk-Browser zeigte erst Fehlermeldung (Verbindungsverlust), konnte aber nach einigen Sekunden durch Neuladen wieder den Dienst nutzen. Ebenso wurde das Szenario Stromausfall geübt: Alle Komponenten aus und wieder an – nach Boot standen WLAN und Backend nach ca. 1 Minute wieder bereit, und das System funktionierte ohne manuellen Eingriff. Die einzige Nacharbeit wäre bei einem Zertifikatstausch nötig, was hier nicht vorkam.

Die Testphase zeigte, dass alle definierten Anforderungen erfüllt wurden. Kleinere Probleme, die entdeckt wurden (z.B. eine falsche Fehlermeldung bei abgelaufenem OTP, oder ein Darstellungsproblem im Kiosk-Browser bei bestimmter Auflösung) konnten noch vor Projektabschluss behoben werden. Mit den erfolgreichen Tests war der Weg frei für die Abnahme und Inbetriebnahme des Systems.

## Projektabschluss

Nachdem Entwicklung und interner Test abgeschlossen waren, wurde das Projekt offiziell beendet und an den Auftraggeber übergeben. Im Rahmen des Projektabschlusses fanden folgende Aktivitäten statt:

**Soll-Ist-Vergleich:** Es wurde ein Abgleich der erzielten Ergebnisse mit den zu Projektbeginn formulierten Zielen durchgeführt. Alle Muss-Anforderungen wurden erreicht, und auch einige optionale Verbesserungen konnten integriert werden:

* Die Druckerreservierung und Freigabe funktionierten im Offline-Netzwerk planmäßig. Gäste konnten selbstständig Anfragen stellen; Administratoren behielten die Kontrolle über die Freigabe.
* Die Smart-Plug-Steuerung über den Tapo P110 klappte zuverlässig ohne Cloud-Anbindung. Das zuvor bestehende manuelle Ein- und Ausschalten des Druckers wurde vollständig durch das digitale System ersetzt.
* Sicherheit und Zugriffsschutz entsprachen den Erwartungen: Unbefugte Zugriffe wurden verhindert, und vertrauliche Daten (Passwörter, OTP-Codes) waren zu keiner Zeit unverschlüsselt im Netzwerk.
* Der Aspekt der **Digitalen Vernetzung** wurde in idealer Weise umgesetzt: Unterschiedlichste Komponenten (Webserver, Datenbank, IoT-Gerät, WLAN/LAN) kommunizieren nahtlos und schaffen zusammen einen neuen digitalisierten Geschäftsprozess.
* Die Umsetzung blieb innerhalb des Zeit- und Budgetrahmens. Tatsächlich wurden rund 65 Stunden für Entwicklung und Test benötigt und weitere ca. 12 Stunden für Dokumentation und Übergabe – somit wurde die geplante 70-Stunden-Marke geringfügig überschritten, was jedoch im Ausbildungsprojekt toleriert wurde. Finanziell entstanden nur geringe Kosten für Steckdose und evtl. ein neues Raspberry-Pi-Netzteil; die meiste Hardware war bereits vorhanden.

**Abnahme durch den Auftraggeber:** In einer abschließenden Präsentation wurde das System dem zuständigen Verantwortlichen vorgeführt. Dabei wurden die wichtigsten Anwendungsfälle live demonstriert: ein Gast stellte eine Anfrage, der Admin genehmigte per Webinterface, der Druck wurde mittels OTP gestartet. Der Auftraggeber prüfte insbesondere die Sicherheit (z.B. Versuch, ohne Freigabe zu drucken – was fehlschlug) und die Nutzerfreundlichkeit (ein nicht IT-affiner Kollege übernahm die Rolle des Gastes und konnte den Ablauf erfolgreich durchführen). Das Feedback war durchweg positiv. Kleinere Verbesserungsvorschläge des Auftraggebers betrafen vor allem Komfort-Funktionen, etwa:

* Eine E-Mail-Benachrichtigung an den Admin zusätzlich (derzeit wegen Offline nicht möglich, aber evtl. SMS über GSM-Stick als Idee).
* Eine Druckfunktion, bei der der Gast sein Dokument direkt hochladen kann. Dies war bewusst aus Projektumfang ausgeschlossen worden, könnte aber in Zukunft als Modul ergänzt werden, falls Internet oder ein lokaler Fileshare verfügbar ist.
* Ein Report am Monatsende, der alle Druckvorgänge auflistet (Nutzer, Zeiten) zur internen Statistik. Das System sammelt diese Daten bereits (im Log), aber ein Export/Report wurde noch nicht implementiert.

Diese Punkte wurden als **Ausblick** formuliert. Sie zeigen, dass das System erweiterbar ist und zukünftig mit überschaubarem Aufwand ergänzt werden kann, wenn es in Dauerbetrieb bleibt.

**Projektdokumentation und Unterlagen:** Alle wichtigen Dokumente wurden dem Auftraggeber bzw. Prüfungsausschuss übergeben. Dazu zählen:

* Diese Projektdokumentation, welche den Verlauf und die technischen Details festhält.
* Der Quellcode des Projekts (als ZIP-File und in einem Git-Repository), inklusive Installationshinweisen.
* Eine kurze **Bedienungsanleitung (Kundendokumentation)** für Administratoren und Nutzer, um den Umgang mit dem System im Alltag zu erleichtern (siehe nächster Abschnitt).
* Ein Zeitnachweis, der die einzelnen Phasen und aufgewendeten Stunden dokumentiert.
* Der ursprüngliche Projektantrag und die Genehmigung der IHK (als Kopie im Anhang).

**Reflexion:** Rückblickend verlief das Projekt erfolgreich und lehrreich. Insbesondere das Einarbeiten in die IoT-Geräte-Kommunikation (Smart-Plug) und die eigenständige Konfiguration eines abgetrennten Netzwerks stellten wertvolle praktische Erfahrungen dar. Einige Herausforderungen, wie die Notwendigkeit eines lokalen NTP-Servers oder die Integration zweier unterschiedlicher Frontends, wurden erfolgreich gemeistert. Aus Projektmanagement-Sicht war die Zeitplanung realistisch: die kritischen Entwicklungsaufgaben konnten rechtzeitig gelöst werden, wodurch genügend Puffer für Tests blieb.

Im Hinblick auf die Ausbildung zum Fachinformatiker Digitale Vernetzung hat das Projekt deutlich gemacht, wie wichtig ein ganzheitlicher Blick auf vernetzte Systeme ist. Es reicht nicht, nur zu programmieren – man muss auch Netzwerkaspekte (IP-Planung, Routing, Security) sowie Hardware in die Lösung einbeziehen. Genau diese Schnittstellenkompetenz wurde hier angewendet.

**Fazit:** Das Projekt *Manage Your Printer* erreichte sein Hauptziel, den Druckerfreigabe-Prozess zu digitalisieren und zu sichern. Der manuelle Aufwand wurde minimiert, und Nutzern steht ein zuverlässiger Service zur Verfügung. Der modulare Aufbau ermöglicht es, das System an veränderte Anforderungen anzupassen (z.B. weitere Geräte, Online-Anbindung, mehr Automatisierung). Somit kann der Ausbildungsbetrieb bzw. der Auftraggeber das System in der Praxis einsetzen und bei Bedarf weiterentwickeln. Die erfolgreiche Umsetzung wurde durch den Abnahmebereicht bestätigt, und das System ging anschließend in den internen Echtbetrieb über.

## Kundendokumentation

Die folgende Anleitung richtet sich an  **Benutzer des Druckerreservierungssystems „MYP – Manage Your Printer“** , insbesondere an gastierende Nutzer (Gäste) sowie Administratoren, die das System verwalten. Sie erläutert die Bedienung aus Anwendersicht. Das System besteht aus einem Webportal und einem Drucker-Kiosk. Für die Nutzung sind keine besonderen IT-Kenntnisse erforderlich; folgen Sie einfach den Schritten in dieser Dokumentation.

### 5.1 Überblick zum System

MYP – *Manage Your Printer* ermöglicht es, Drucker in einer geschützten Umgebung auf Anfrage freizugeben. Der Drucker ist standardmäßig ausgeschaltet und wird erst aktiv, wenn ein autorisierter Druckvorgang stattfinden soll. Die Kommunikation mit dem System erfolgt über eine Web-Oberfläche, die sowohl von Ihrem eigenen Gerät (z.B. Laptop, Smartphone über WLAN) als auch über das fest installierte Kiosk-Terminal am Drucker verfügbar ist.

Es gibt zwei Arten von Benutzern:

* **Gast** – Ein Gast ist ein Nutzer, der einen Druckauftrag stellen möchte. Gäste können Druckanfragen einreichen und erhalten bei Freigabe einen einmaligen Code zum Starten des Druckers.
* **Administrator** – Ein Administrator ist typischerweise ein Mitarbeiter des Veranstalters oder der Einrichtung, der die Kontrolle über den Drucker behält. Administratoren sehen alle eingehenden Anfragen und entscheiden über Freigabe oder Ablehnung. Außerdem können sie bei Bedarf den Drucker manuell ein- und ausschalten sowie Benutzerkonten verwalten.

**Ablauf in Kürze:** Ein Gast stellt über die Weboberfläche eine Anfrage und gibt ggf. einen gewünschten Druckzeitpunkt an. Der Administrator prüft die Anfrage und genehmigt sie, wenn keine Konflikte oder Einwände bestehen. Das System generiert daraufhin einen Einmal-Code (OTP). Der Gast erhält diesen Code (angezeigt im Webportal) und nutzt ihn zur vorgesehenen Zeit am Drucker, um den Drucker einzuschalten. Nach Eingabe des Codes wird der Drucker für eine begrenzte Dauer mit Strom versorgt, sodass der Gast sein Dokument drucken kann. Anschließend schaltet sich der Drucker wieder ab.

Die Weboberfläche ist über das lokale WLAN **„MYP-Print“** erreichbar. Stellen Sie sicher, dass Sie mit dem WLAN verbunden sind (fragen Sie ggf. das Personal nach dem WLAN-Schlüssel). Auf dem Kiosk-Terminal ist die Oberfläche bereits geöffnet.

### 5.2 Anleitung für Gäste (Drucknutzer)

**Schritt 1: Anmeldung im Webportal**

Als Gast benötigen Sie ein Benutzerkonto, das Ihnen vom Administrator mitgeteilt wird (Benutzername und Passwort). Verbinden Sie Ihr Gerät mit dem WLAN „MYP-Print“. Öffnen Sie dann einen Browser und rufen Sie die Seite `https://myp-backend/` auf. (Alternativ können Sie die IP-Adresse direkt verwenden, z.B. `https://192.168.0.105/`, falls der Name nicht auflöst. In vielen Fällen öffnet sich auch automatisch eine Portal-Seite nach dem WLAN-Login.) Sie sehen nun die Anmeldeseite. Geben Sie Ihren Benutzernamen und Ihr Passwort ein und klicken Sie auf „Anmelden“. Sollte ein Sicherheitszertifikat-Hinweis erscheinen, akzeptieren Sie das Zertifikat – dies liegt daran, dass wir ein internes Zertifikat verwenden.

*Hinweis:* Falls Sie kein eigenes Gerät nutzen möchten, können Sie zum am Drucker aufgestellten Kiosk-Terminal gehen. Dort ist das System bereits geöffnet. Melden Sie sich auch dort mit Ihren Zugangsdaten an. Das Terminal verfügt über einen Touchscreen bzw. eine einfache Bedienung mit Maus und Tastatur.

**Schritt 2: Druckanfrage stellen**

Nach erfolgreicher Anmeldung sehen Sie das Gast-Panel. Hier können Sie eine neue **Druckanfrage** erstellen. Je nach Interface sieht dies etwas unterschiedlich aus:

* In der mobilen/Browser-Version klicken Sie auf „Neue Druckanfrage“ oder es erscheint direkt ein Formular. Geben Sie hier die benötigten Informationen ein. Typischerweise: *Gewünschter Druckzeitpunkt* (Datum und Uhrzeit oder „sofort möglichst“), sowie eine kurze Beschreibung oder Betreff (z.B. „10 Seiten PDF-Dokument“). Falls Sie an einem bestimmten Tag/Uhrzeit drucken möchten, wählen Sie diesen im Kalender aus, der angezeigt wird. Freie Zeitfenster sind dort erkennbar.
* Am Kiosk-Terminal tippen Sie auf „Drucken anfragen“. Sie werden ggf. aufgefordert, einen Zeitpunkt auszuwählen und eine Beschreibung einzugeben. Nutzen Sie die Bildschirmtastatur, falls keine physische Tastatur vorhanden ist.

Haben Sie alle Angaben gemacht, bestätigen Sie mit „Anfrage senden“. Ihr Antrag wird nun im System gespeichert und dem Administrator zur Prüfung vorgelegt. Sie sehen anschließend eine Statusanzeige, z.B. „Anfrage eingereicht am [Zeit] – wartet auf Entscheidung“.

**Schritt 3: Warten auf Freigabe**

Der Administrator erhält nun Ihre Anfrage. Bitte haben Sie Geduld, bis die Anfrage bearbeitet ist. Sie müssen die Seite nicht ständig neu laden; das System aktualisiert den Status automatisch alle halbe Minute. Sobald der Admin eine Entscheidung getroffen hat, sehen Sie eine Aktualisierung:

* **Falls abgelehnt:** Es erscheint eine Meldung „Ihre Anfrage wurde abgelehnt.“ Möglicherweise wird ein Grund angegeben (z.B. „Drucker heute nicht verfügbar“). In diesem Fall können Sie bei Bedarf eine neue Anfrage zu einem anderen Zeitpunkt stellen oder Rücksprache mit dem Personal halten.
* **Falls genehmigt:** Gratulation, Ihr Druckauftrag wurde genehmigt! Sie sehen nun eine Nachricht „Anfrage genehmigt“. Ihnen wird ein **einmaliger Code** angezeigt, meist eine 6-stellige Zahl (z.B. `749201`). Dies ist Ihr persönlicher Druckcode.

Notieren Sie sich diesen Code oder merken Sie ihn sich gut. **Wichtig:** Dieser Code ist zeitlich begrenzt gültig. Nutzen Sie ihn daher möglichst zeitnah zum angegebenen Druckzeitpunkt. Wenn Sie den Druck zur späteren Zeit angefragt haben, nutzen Sie den Code erst dann.

**Schritt 4: Druckauftrag durchführen (OTP-Code eingeben)**

Begeben Sie sich zum Druckerstandort (falls Sie nicht schon dort am Kiosk sind). Um den Drucker einzuschalten, müssen Sie nun Ihren Code eingeben:

* **Am Kiosk-Terminal:** Auf dem Bildschirm sollte ein Feld zur Code-Eingabe zu sehen sein (überschrieben mit „Bitte geben Sie Ihren Druckcode ein“). Tippen Sie Ihren 6-stelligen Code ein. Bei Touch-Bedienung steht Ihnen ein Ziffernfeld zur Verfügung – drücken Sie die entsprechenden Ziffern und bestätigen Sie mit „OK“ oder „Start“.
* **Mit eigenem Gerät:** Falls Sie den Drucker selbst ansteuern (z.B. weil Sie vom eigenen Laptop drucken möchten, der mit dem Drucker verbunden ist), öffnen Sie in Ihrem Browser die Seite zur Code-Eingabe. Klicken Sie im Portal auf „Druck starten“ – es öffnet sich eine Eingabemaske für den OTP-Code. Geben Sie dort die Zahlen ein und bestätigen Sie.

Nach Eingabe des korrekten Codes wird das System verifizieren, ob alles in Ordnung ist. Dies dauert nur einen kurzen Moment (1–2 Sekunden). Ist der Code richtig und gültig, erhalten Sie die Meldung „Drucker ist jetzt freigeschaltet“ und meistens hören Sie ein leises „Klack“, wenn die Steckdose den Drucker einschaltet. Jetzt können Sie Ihr Dokument drucken:

* Falls der Drucker netzwerkfähig ist und Sie vom Laptop drucken: Senden Sie nun den Druckjob an den Drucker (der Drucker sollte nun online angezeigt werden, evtl. müssen Sie einmal auf „Verbinden“ klicken).
* Falls der Drucker per USB-stick oder am Kiosk bedient wird: Folgen Sie den Anweisungen vor Ort, z.B. Dokument vom USB-Stick über das Kiosk-Terminal drucken. (Anmerkung: Je nach Einrichtung wird entweder Personal den Druck auslösen oder es gibt ein Self-Service am PC.)

Sobald Sie Ihren Druck erledigt haben, lassen Sie den Drucker einfach eingeschaltet. Das System wird ihn nach einer festgelegten Zeit automatisch wieder ausschalten. Sie müssen nichts weiter tun. In der Weboberfläche wird Ihre Anfrage nun als *abgeschlossen* markiert.

**Fehlerfälle und Hinweise:**

* Wenn Sie einen falschen Code eingeben, erhalten Sie die Meldung „Falscher Code, bitte erneut versuchen.“ Achten Sie darauf, sich nicht zu vertippen. Nach drei Fehleingaben wird der Vorgang aus Sicherheitsgründen gesperrt – wenden Sie sich dann an das Personal.
* Wenn Sie zu lange warten und der Code abläuft (z.B. Gültigkeit 15 Minuten überschritten), erscheint die Meldung „Code abgelaufen“. In diesem Fall kontaktieren Sie den Administrator für eine erneute Freigabe. Es kann sein, dass Sie dann eine neue Anfrage stellen müssen, je nach Regelung vor Ort.
* Sollte der Drucker trotz korrekten Codes nicht einschalten (kein Geräusch, keine Status-LED am Drucker), prüfen Sie die Verbindung: Ist die Steckdose eingesteckt? Leuchtet an der Steckdose eine Lampe? Eventuell liegt ein technisches Problem vor – informieren Sie dann bitte das Personal.

**Schritt 5: Abmeldung**

Nach getaner Arbeit können Sie sich aus dem Webportal abmelden. Klicken Sie auf Ihren Benutzernamen (oder das Menü) und wählen Sie „Abmelden“. Dies ist besonders wichtig, wenn Sie das Kiosk-Terminal genutzt haben, damit kein nachfolgender Nutzer auf Ihr Konto zugreifen kann. Am Kiosk-Terminal erfolgt aus Sicherheitsgründen nach einigen Minuten Inaktivität automatisch eine Abmeldung.

### 5.3 Anleitung für Administratoren

Für Administratoren gibt es ein spezielles Admin-Panel, über das die Verwaltung der Druckanfragen und Benutzer erfolgt. Als Administrator haben Sie einen eigenen Login (mit Administratorrechten). Stellen Sie zunächst sicher, dass Ihr Gerät mit dem internen Netzwerk verbunden ist (im Büro-LAN oder ebenfalls im WLAN „MYP-Print“, je nach Systemkonfiguration).

**Anmeldung als Admin:** Öffnen Sie das Webportal wie oben (`https://myp-backend/` im Browser). Loggen Sie sich mit Ihrem Admin-Benutzernamen und Passwort ein. Sie gelangen nun in die Admin-Oberfläche. Diese unterscheidet sich von der Gast-Ansicht: Sie sehen sofort eine Liste aller aktuellen Druckanfragen und zusätzliche Menüpunkte.

**Anfragen verwalten:** Im Hauptbereich „Druckanfragen“ sind alle *offenen* Anfragen aufgeführt, meist mit Angaben wie Benutzername des Gastes, angefragter Zeitpunkt und Beschreibung. Prüfen Sie regelmäßig, ob neue Anfragen vorliegen – neue Einträge werden farblich hervorgehoben oder es erscheint ein Hinweis „Neue Anfrage eingegangen“.

Für jede Anfrage haben Sie folgende Optionen:

* **Details ansehen:** Klicken Sie auf die Anfrage, um alle Informationen anzuzeigen (gewünschte Zeit, ggf. Kommentar des Gastes, bisherige Anfragen dieses Nutzers etc.).
* **Genehmigen:** Ist die Anfrage in Ordnung und kein Konflikt vorhanden, können Sie auf „Genehmigen“ klicken. Bestätigen Sie den Vorgang, falls eine Sicherheitsabfrage erscheint. Das System wird nun im Hintergrund einen OTP-Code generieren und die Anfrage als genehmigt kennzeichnen. Der Gast wird automatisch benachrichtigt. Sie sehen dann den Code ebenfalls in der Detailansicht der Anfrage (falls Sie ihn dem Gast manuell mitteilen möchten).
* **Ablehnen:** Falls Sie die Anfrage nicht zulassen können oder wollen, klicken Sie auf „Ablehnen“. Es erscheint ein Feld, in dem Sie optional einen **Ablehnungsgrund** eingeben können (z.B. „Zeitfenster überschneidet sich mit Wartung“ oder „Keine Farbdrucke möglich“). Bestätigen Sie die Ablehnung. Der Gast erhält über das Portal die Mitteilung mit Ihrem angegebenen Hinweis.

**Reservierungen/Kalender:** Über den Menüpunkt „Kalender“ oder im Dashboard sehen Sie eine Übersicht aller genehmigten und geplanten Drucktermine. Hier erkennen Sie, wann der Drucker reserviert ist. Dies hilft Ihnen auch, zukünftige Anfragen einzuschätzen – sollte ein Gast eine Anfrage für einen bereits belegten Slot stellen, wird das System das verhindern, aber Sie können proaktiv planen. Sie haben im Admin-Panel ggf. die Möglichkeit, Einträge im Kalender zu bearbeiten (z.B. verschieben oder löschen), was direkt auf die Anfragen wirkt. Ändern Sie jedoch Reservierungen nur in Absprache mit dem jeweiligen Gast.

**Steckdose manuell steuern:** In Ausnahmefällen möchten Sie den Drucker vielleicht unabhängig vom OTP-Prozess ein- oder ausschalten (z.B. für Wartung, Testdrucke oder Notfälle). In der Admin-Oberfläche gibt es dafür einen Bereich „Steckdosensteuerung“ oder „Gerätesteuerung“. Dort finden Sie einen Schalter „Drucker AN/AUS“. Dieser zeigt den aktuellen Status der Steckdose (Grün = an, Rot = aus). Sie können darauf klicken, um die Steckdose direkt zu schalten. Beachten Sie: Wenn Sie den Drucker manuell einschalten, wird dies im System protokolliert, aber es ist kein OTP erforderlich – nutzen Sie dies also nur intern. Vergessen Sie nicht, den Drucker anschließend wieder auszuschalten, da sonst ein Gast ohne Code drucken könnte. Das System schaltet den Drucker nach einer bestimmten Leerlaufzeit zwar automatisch ab, aber manuelle Kontrolle ist hier wichtig.

**Benutzerverwaltung:** Unter „Benutzer“ können Sie die registrierten Konten einsehen. Für jeden Gast ist ein Account angelegt. Sie können neue Benutzer hinzufügen (z.B. wenn neue Gäste berechtigt werden sollen). Klicken Sie auf „Benutzer hinzufügen“, vergeben Sie einen Benutzernamen und ein initiales Passwort und eine Rolle (Gast oder Admin). Teilen Sie neue Zugangsdaten den betreffenden Personen vertraulich mit. Bestehende Benutzer können bearbeitet werden – z.B. Passwort zurücksetzen, falls jemand sein Passwort vergessen hat. Aus Sicherheitsgründen werden Passwörter nur gehashed gespeichert; Sie können also kein vergessenes Passwort einsehen, sondern nur neu setzen. Sie können Benutzer auch deaktivieren oder löschen, falls jemand keinen Zugang mehr haben soll.

**Systemüberwachung und Logbuch:** Das System protokolliert wichtige Ereignisse im Hintergrund. Im Admin-Bereich gibt es oft ein „Log“ oder „Aktivitäten“. Dort sehen Sie z.B. „[Zeit] Benutzer MaxMuster hat Druckanfrage #5 gestellt“ oder „[Zeit] Admin hat Anfrage #5 genehmigt (Code 749201)“ usw. Dieses Log hilft bei der Nachverfolgung. Sie können hierdurch auch Unregelmäßigkeiten feststellen (z.B. falls jemand mehrfach falschen Code eingegeben hat). Das Log wird bei Bedarf automatisch bereinigt, um es übersichtlich zu halten.

**Wartung des Systems:** Als Administrator kümmern Sie sich auch um den Betrieb:

* **Start/Stop des Systems:** Die beiden Raspberry Pi laufen in der Regel 24/7. Sollten Sie sie neu starten müssen (z.B. nach Updates oder falls sich etwas aufgehängt hat), tun Sie dies möglichst außerhalb der reservierten Zeiten. Nach einem Neustart stellen Sie sicher, dass: der Backend-Pi seine Dienste gestartet hat (Webinterface erreichbar) und der Kiosk-Pi das WLAN und den Browser gestartet hat. Normalerweise passiert dies automatisch durch die Konfiguration. Testen Sie einmal das Login und ggf. einen Schaltbefehl, um sicherzugehen.
* **Zertifikate erneuern:** Die SSL-Zertifikate, die für die HTTPS-Verschlüsselung sorgen, haben ein Ablaufdatum (in unserem Fall typisch 10 Jahre gültig, da selbstsigniert). Sollte dennoch ein Tausch anstehen oder Sie dem System ein offizielles Zertifikat geben (wenn es doch ans Internet geht), folgen Sie der technischen Dokumentation im Anhang oder wenden Sie sich an einen IT-Administrator.
* **Updates:** Aktualisieren Sie die Raspberry Pi Systeme in regelmäßigen Abständen, sofern das System länger in Betrieb ist. Da kein Internet besteht, könnte man nötige Updates via USB einspielen. Wichtig ist insbesondere, Sicherheitsupdates ins System zu bringen, auch wenn das Netzwerk isoliert ist.
* **Backups:** Das System speichert Daten (Benutzer, Anfragen) in einer SQLite-Datei auf dem Backend-Pi. Machen Sie hiervon in sinnvollen Abständen eine Sicherheitskopie, um bei Hardwareproblemen keinen Datenverlust zu riskieren. Sie können dazu z.B. per SCP die `myp.db` Datei auf einen USB-Stick oder Admin-PC kopieren.
* **Reset der Steckdose:** Sollte die Smart-Steckdose nicht mehr reagieren (z.B. nach Stromausfall blinkt rot und verbindet nicht), müssen Sie sie evtl. neu ins WLAN aufnehmen. Dafür drücken Sie den kleinen Knopf an der Seite 5 Sekunden (bis das Licht schnell blinkt) und folgen der TP-Link-Anleitung zur Neueinrichtung – idealerweise aber unter Anleitung eines Technikers, da diese Konfiguration Teil des technischen Systems ist.

**Support für Nutzer:** Weisen Sie Gastnutzer ein, wie sie das System verwenden (im Prinzip wie in Kapitel 5.2 beschrieben). Stellen Sie das ausgehängte Infoblatt mit den Schritten in Sichtweite des Kiosk-Terminals auf. Bei Problemen stehen Sie als Administrator zur Verfügung. Häufige Fragen werden sein: „Wie bekomme ich Zugangsdaten?“, „Ich habe meinen Code vergessen/verloren – was tun?“ (Antwort: Code im Admin-Interface nochmals nachschauen oder Anfrage stornieren und neu anlegen).

Mit dieser Kundendokumentation sollten sowohl Gäste als auch Administratoren in der Lage sein, das  *Manage Your Printer* -System effektiv zu nutzen. Halten Sie diese Dokumentation griffbereit und passen Sie sie bei Änderungen des Systems entsprechend an.

## Anhang

**A. Projektantrag und Genehmigung:**

Im Anhang A befindet sich der ursprüngliche Projektantrag „Entwicklung eines Druckerreservierungssystems mit Offline-Netzwerk“ sowie das Schreiben der IHK zur Genehmigung des Projektthemas. Darin sind die Projektbeschreibung, Zielsetzung und Rahmenbedingungen nochmals zusammengefasst.

**B. Zeitnachweis (Projektzeiterfassung):**

Anhang B enthält eine tabellarische Aufstellung der durchgeführten Arbeitspakete mit Datumsangaben und Stundeneinsatz. Diese Übersicht dokumentiert den Projektverlauf und dient als Nachweis, dass der Prüfling die vorgegebenen 70 Stunden eigenständig durchgeführt hat. Die Tabelle ist unterteilt nach Phasen (Planung, Umsetzung, Test, Dokumentation) und zeigt die jeweiligen Tätigkeiten (z.B. „Installation Raspberry Pi Backend – 2h“, „Implementierung Login und Rollen – 4h“ etc.) mit Summe.

**C. Technische Dokumentationen und Listings:**

* **C.1 Netzwerkplan:** Ein Diagramm, das die Netzwerktopologie darstellt (Raspberry Pi Backend im LAN, Raspberry Pi Kiosk als WLAN-AP, Smart Plug, Printer). Darin sind IP-Adressen, Subnetze und Verbindungen ersichtlich, um technischen Betreuern einen schnellen Überblick zu geben.
* **C.2 Konfigurationsdateien (Auszüge):** Wichtige Konfigurationsdateien sind hier gelistet, z.B. Ausschnitte aus `hostapd.conf` (WLAN-Name, Verschlüsselungseinstellungen), `dnsmasq.conf` (DHCP-Range, DNS Overrides für NTP), und `flask_config.py` (Einstellungen des Flask-Servers, soweit sie keine Passwörter enthalten). Diese dienen dazu, das System bei Bedarf rekonstruieren oder anpassen zu können.
* **C.3 Quellcode-Auszug SmartPlug-Steuerung:** Da diese Komponente besonders examensrelevant war, ist hier der Python-Code abgedruckt, der den Anmelde- und Schaltvorgang der Tapo P110 durchführt. Kommentare im Code erläutern den Ablauf. Der vollständige Code ist im beigelegten Repository enthalten; hier wird eine gekürzte Fassung gezeigt, um die Kernlogik hervorzuheben.
* **C.4 API-Endpunkt-Übersicht:** Eine Tabelle, die alle entwickelten REST-API-Endpunkte mit kurzem Zweck, Method (GET/POST...) und erforderlichen Rechten auflistet. Dies ist hilfreich für zukünftige Entwickler oder Integrationen, die auf das System zugreifen wollen.

**D. Tests und Abnahmeprotokoll:**

In Anhang D findet sich das Testprotokoll mit einer Checkliste aller Testfälle und den Ergebnissen (Bestanden/Nicht bestanden, Bemerkungen). Ebenso ist ein Abnahmeprotokoll beigefügt, das vom Auftraggeber unterzeichnet wurde. Dieses bestätigt, dass das System gemäß den Anforderungen umgesetzt wurde und betriebsbereit ist.

**E. Benutzerhandbuch (kurz) und Schulungsunterlagen:**

Falls ergänzend erstellt, enthält Anhang E z.B. ein zweiseitiges Kurzhandbuch, das den Ablauf für Gäste in knapper Form darstellt (dies kann z.B. aushängen) und ggf. Folien oder Notizen aus einer internen Schulung des Personals.

*Dokumentation Ende.*
