# 📋 Rechtliche Seiten - MYP Platform

## 🎯 Überblick

Das MYP-System verfügt über umfassende rechtliche Seiten, die alle erforderlichen Informationen für den Betrieb in einer Unternehmensumgebung bereitstellen.

## 📄 Verfügbare Seiten

### 1. **Impressum** (`/imprint`)
- **Zweck**: Rechtliche Pflichtangaben gemäß § 5 TMG
- **Template**: `templates/imprint.html`
- **Route**: `@app.route("/imprint")`

#### Inhalte:
- ✅ **Unternehmensinformationen** (Mercedes-Benz AG)
- ✅ **Kontaktdaten** (E-Mail, Telefon, Adresse)
- ✅ **Rechtliche Angaben** (Registergericht, Umsatzsteuer-ID)
- ✅ **Verantwortliche Person** (Till Tomczak)
- ✅ **Haftungsausschluss** (Inhalte, Links, Urheberrecht)
- ✅ **Streitschlichtung** (EU-Plattform)
- ✅ **System-Information** (MYP Platform Details)

### 2. **Rechtliche Hinweise** (`/legal`)
- **Zweck**: Umfassende rechtliche Dokumentation
- **Template**: `templates/legal.html`
- **Route**: `@app.route("/legal")`

#### Inhalte:
- 🛡️ **Datenschutzerklärung** (DSGVO-konform)
- 📋 **Allgemeine Nutzungsbedingungen**
- 🍪 **Cookie-Richtlinie**
- 🔒 **Sicherheitsrichtlinien**

## 🎨 Design-Features

### **Responsive Layout**
- ✅ Mobile-optimiert
- ✅ Tablet-friendly
- ✅ Desktop-optimiert

### **Navigation**
- ✅ Smooth-Scrolling zu Sektionen
- ✅ Scroll-to-Top Button
- ✅ Breadcrumb-Navigation
- ✅ Cross-Links zwischen Seiten

### **Visuelle Elemente**
- ✅ Color-coded Sektionen
- ✅ Font Awesome Icons
- ✅ Tailwind CSS Styling
- ✅ Card-basiertes Layout

## 📊 Datenschutzerklärung Details

### **Datenerhebung**
```
Registrierungsdaten:
- Benutzername
- E-Mail-Adresse (Mercedes-Benz)
- Name und Abteilung
- Rolle im System

Nutzungsdaten:
- Druckaufträge und -verlauf
- Login-Zeiten und -Häufigkeit
- IP-Adresse und Browser-Info
- Systemaktivitäten
```

### **Rechtliche Grundlagen**
- **Art. 6 Abs. 1 lit. b DSGVO**: Vertragserfüllung
- **Art. 6 Abs. 1 lit. f DSGVO**: Berechtigte Interessen
- **Art. 6 Abs. 1 lit. c DSGVO**: Rechtliche Verpflichtung

### **Benutzerrechte**
- ✅ Auskunftsrecht (Art. 15 DSGVO)
- ✅ Berichtigungsrecht (Art. 16 DSGVO)
- ✅ Löschungsrecht (Art. 17 DSGVO)
- ✅ Einschränkungsrecht (Art. 18 DSGVO)
- ✅ Datenübertragbarkeit (Art. 20 DSGVO)
- ✅ Widerspruchsrecht (Art. 21 DSGVO)

## 🔒 Sicherheitsrichtlinien

### **Technische Maßnahmen**
```
Infrastruktursicherheit:
- HTTPS-Verschlüsselung
- Sichere Datenübertragung
- Regelmäßige Security-Updates
- Firewalls und Intrusion Detection

Anwendungssicherheit:
- Sichere Authentifizierung
- Rollenbasierte Zugriffskontrolle
- Input-Validierung
- Session-Management
```

### **Benutzer-Empfehlungen**
```
Passwort-Sicherheit:
- Starke Passwörter verwenden
- Keine Zugangsdaten teilen
- Nach Nutzung abmelden
- Nicht öffentliche Computer verwenden

Allgemeine Sicherheit:
- Browser aktuell halten
- Antivirus-Software verwenden
- Vorsicht bei Downloads
- Verdächtige Aktivitäten melden
```

## 🍪 Cookie-Management

### **Cookie-Kategorien**
```
Technisch notwendige Cookies:
- Session-Management
- Anmeldestatus
- CSRF-Schutz
- Spracheinstellungen

Funktionale Cookies:
- Benutzereinstellungen
- Dashboard-Konfiguration
- Theme-Präferenzen
- Accessibility-Optionen
```

### **Browser-Einstellungen**
- ✅ Chrome: Einstellungen → Datenschutz und Sicherheit → Cookies
- ✅ Firefox: Einstellungen → Datenschutz & Sicherheit
- ✅ Edge: Einstellungen → Cookies und Websiteberechtigungen

## 📋 Nutzungsbedingungen

### **Erlaubte Nutzung**
- ✅ Druckaufträge für Ausbildungszwecke
- ✅ Prototyping und Projektarbeit
- ✅ Lernmaterialien und Demonstrationen
- ✅ Interne Mercedes-Benz Projekte

### **Verbotene Nutzung**
- ❌ Kommerzielle Zwecke ohne Genehmigung
- ❌ Urheberrechtsverletzungen
- ❌ Gefährliche oder illegale Objekte
- ❌ Systemmanipulation oder -missbrauch

## 🛠️ Technische Implementation

### **Template-Struktur**
```html
{% extends "base.html" %}
{% block title %}{{ title }} - MYP Platform{% endblock %}
{% block content %}
  <!-- Seiteninhalt -->
{% endblock %}
```

### **Navigation-Integration**
```python
# In app.py
@app.route("/imprint")
def imprint():
    return render_template("imprint.html", title="Impressum")

@app.route("/legal")
def legal():
    return render_template("legal.html", title="Rechtliche Hinweise")
```

### **JavaScript-Features**
```javascript
// Smooth Scrolling
document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
        e.preventDefault();
        const target = document.querySelector(this.getAttribute('href'));
        if (target) {
            target.scrollIntoView({
                behavior: 'smooth',
                block: 'start'
            });
        }
    });
});

// Scroll-to-Top
const scrollToTopBtn = document.getElementById('scrollToTop');
window.addEventListener('scroll', () => {
    if (window.pageYOffset > 300) {
        scrollToTopBtn.classList.remove('opacity-0', 'pointer-events-none');
        scrollToTopBtn.classList.add('opacity-100');
    } else {
        scrollToTopBtn.classList.add('opacity-0', 'pointer-events-none');
        scrollToTopBtn.classList.remove('opacity-100');
    }
});
```

## 🔧 Konfiguration

### **Mercedes-Benz Spezifische Daten**
```
Unternehmen: Mercedes-Benz AG
Adresse: Mercedes-Benz Platz 1, 70546 Stuttgart
Registergericht: Amtsgericht Stuttgart, HRB 19360
Umsatzsteuer-ID: DE811944017
Kontakt: till.tomczak@mercedes-benz.com
```

### **System-Information**
```
Platform: MYP (Manage Your Printers)
Version: 2.0.0
Abteilung: Ausbildungsabteilung - 3D-Druck
Entwicklung: Mercedes-Benz AG (Interne Projektarbeit)
```

## 📱 Mobile Responsiveness

### **Breakpoints**
- **Mobile**: < 768px
- **Tablet**: 768px - 1024px
- **Desktop**: > 1024px

### **Mobile Optimierungen**
- ✅ Touch-friendly Buttons
- ✅ Readable Font-Größen
- ✅ Optimierte Navigation
- ✅ Kompakte Layouts

## ⚡ Performance-Features

### **Optimierungen**
- ✅ Lazy Loading für Bilder
- ✅ Minimierte CSS/JS
- ✅ Optimierte Ladezeiten
- ✅ Effiziente DOM-Manipulation

### **Caching**
- ✅ Browser-Caching für statische Assets
- ✅ Template-Caching
- ✅ Optimierte Ressourcen-Lieferung

## 🔄 Wartung und Updates

### **Regelmäßige Überprüfungen**
- ✅ Rechtliche Compliance
- ✅ DSGVO-Konformität
- ✅ Link-Validierung
- ✅ Inhaltsaktualisierungen

### **Automatische Updates**
- ✅ Datum der letzten Aktualisierung
- ✅ Versionskontrolle
- ✅ Change-Log-Integration

## 📞 Support und Kontakt

Bei Fragen zu den rechtlichen Seiten:
- **E-Mail**: till.tomczak@mercedes-benz.com
- **Abteilung**: Ausbildungsabteilung - 3D-Druck
- **System**: MYP Platform Support

---

*Diese Dokumentation wurde automatisch generiert und ist Teil des MYP Platform Projekts.* 