@echo off
REM =======================================================
REM AUTOMATISCHES SCREENSHOT-TOOL FÜR SCHULUNGEN
REM =======================================================
REM 
REM Diese Batch-Datei startet das Screenshot-Tool mit
REM einem einfachen Doppelklick für Mitarbeiterschulungen
REM
REM Erstellt: 16.01.2025
REM =======================================================

title Screenshot-Tool für Schulungen

echo.
echo ===============================================
echo    🎯 SCREENSHOT-TOOL FÜR SCHULUNGEN
echo ===============================================
echo.

REM Zum Skript-Verzeichnis wechseln
cd /d "%~dp0"

REM Prüfe ob PowerShell verfügbar ist
powershell -Command "Write-Host 'PowerShell verfügbar'" >nul 2>&1
if %errorlevel% neq 0 (
    echo ❌ PowerShell nicht gefunden!
    echo 💡 Bitte installieren Sie PowerShell oder verwenden Sie Windows 10+
    pause
    exit /b 1
)

echo ✅ PowerShell gefunden
echo.

REM Frage nach Ausführungsmodus
echo 📋 AUSFÜHRUNGSMODUS WÄHLEN:
echo.
echo [1] Automatisch (Empfohlen)
echo [2] Interaktiv (mit Benutzer-Eingaben)
echo [3] Quick-Run (Schnellstart)
echo [4] Konfiguration bearbeiten
echo [5] Dokumentation öffnen
echo [9] Beenden
echo.
set /p mode="Wählen Sie eine Option (1-5, 9): "

if "%mode%"=="1" goto automatic
if "%mode%"=="2" goto interactive
if "%mode%"=="3" goto quickrun
if "%mode%"=="4" goto config
if "%mode%"=="5" goto docs
if "%mode%"=="9" goto exit
goto invalid

:automatic
echo.
echo 🤖 AUTOMATISCHER MODUS
echo ========================
echo.
powershell -ExecutionPolicy Bypass -File "run_screenshot_tool.ps1"
goto end

:interactive
echo.
echo 🎛️ INTERAKTIVER MODUS
echo =====================
echo.
powershell -ExecutionPolicy Bypass -File "run_screenshot_tool.ps1" -Interactive
goto end

:quickrun
echo.
echo ⚡ QUICK-RUN MODUS
echo ==================
echo.
set /p server_url="Server-URL [http://localhost:5000]: "
if "%server_url%"=="" set server_url=http://localhost:5000

powershell -ExecutionPolicy Bypass -File "run_screenshot_tool.ps1" -QuickRun -ServerUrl "%server_url%"
goto end

:config
echo.
echo ⚙️ KONFIGURATION BEARBEITEN
echo ============================
echo.
if exist "screenshot_config.json" (
    echo 📝 Öffne Konfigurationsdatei...
    notepad "screenshot_config.json"
) else (
    echo ⚠️ Konfigurationsdatei nicht gefunden!
    echo 💡 Erstelle Standard-Konfiguration...
    echo Creating default config...
    powershell -Command "if (Test-Path 'screenshot_config.json') { Write-Host 'Config exists' } else { Write-Host 'Creating default config'; Copy-Item 'screenshot_config.json.template' 'screenshot_config.json' -ErrorAction SilentlyContinue }"
)
echo.
pause
goto start

:docs
echo.
echo 📚 DOKUMENTATION ÖFFNEN
echo ========================
echo.
if exist "..\docs\SCHULUNG_SCREENSHOT_TOOL.md" (
    echo 📖 Öffne Dokumentation...
    start notepad "..\docs\SCHULUNG_SCREENSHOT_TOOL.md"
) else (
    echo ⚠️ Dokumentation nicht gefunden!
    echo 💡 Suche nach alternativen Dokumenten...
    if exist "*.md" (
        echo 📋 Verfügbare Dokumentationsdateien:
        dir /b *.md
    )
)
echo.
pause
goto start

:invalid
echo.
echo ❌ UNGÜLTIGE AUSWAHL
echo ====================
echo.
echo Bitte wählen Sie eine gültige Option (1-5, 9)
echo.
pause
goto start

:end
echo.
echo ===============================================
echo             SCREENSHOT-TOOL BEENDET
echo ===============================================
echo.

REM Prüfe Ausgabe-Ordner
if exist "..\docs\schulung\screenshots" (
    echo 📁 Screenshots verfügbar in:
    echo    %cd%\..\docs\schulung\screenshots
    echo.
    set /p open_folder="📂 Möchten Sie den Screenshot-Ordner öffnen? (j/n): "
    if /i "%open_folder%"=="j" (
        explorer "..\docs\schulung\screenshots"
    )
    if /i "%open_folder%"=="ja" (
        explorer "..\docs\schulung\screenshots"
    )
    if /i "%open_folder%"=="y" (
        explorer "..\docs\schulung\screenshots"
    )
    if /i "%open_folder%"=="yes" (
        explorer "..\docs\schulung\screenshots"
    )
)

echo.
echo 💡 VERWENDUNG FÜR SCHULUNGEN:
echo ================================
echo • Admin-Screenshots: für Administrator-Schulungen
echo • Benutzer-Screenshots: für allgemeine Mitarbeiterschulungen  
echo • Öffentlich-Screenshots: für Kunden-/Gäste-Präsentationen
echo • Desktop-Auflösung: für PowerPoint-Präsentationen
echo • Mobile-Auflösung: für Responsive-Design-Demonstrationen
echo.
echo 🎓 PERFEKT FÜR:
echo • IHK-Präsentationen
echo • Mitarbeiterschulungen
echo • Benutzerhandbücher
echo • System-Dokumentation
echo.

:exit
echo.
echo 👋 Vielen Dank für die Verwendung des Screenshot-Tools!
echo    Für Support: Siehe docs\SCHULUNG_SCREENSHOT_TOOL.md
echo.
pause 